<?php
/**
 *	Module "Company"
 *	Author: Grebenkin Anton
 *	Contact e-mail: 4freework@gmail.com
 */

class PluginCompany_ActionCompanies extends ActionPlugin {
	/**
	 * Главное меню
	 */
	protected $sMenuHeadItemSelect='company';
	/**
	 * Меню
	 */
	protected $sMenuItemSelect='company';
	/**
	 * Субменю
	 */
	protected $sMenuSubItemSelect='all';
	protected $oUserCurrent=null;
	protected $aUserCompany=null;
	protected $aTypes;

	public function Init() {
		$this->SetDefaultEvent('');
		$this->oUserCurrent = $this->User_GetUserCurrent();
		$this->aTypes = Config::Get('module.company.types');
	}

	/**
	 * Регистрация событий
	 */
	protected function RegisterEvent() {
		$this->AddEvent('city','EventShowCompaniesByCity');
		$this->AddEvent('country','EventShowCompaniesByCountry');
		$this->AddEvent('tag','EventShowCompaniesByTag');
		$this->AddEvent('blog','EventShowCorporativeBlogs');
		$this->AddEventPreg('/^my$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowCompanies');
		$this->AddEventPreg('/^new$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowCompanies');
		$this->AddEventPreg('/^moderation$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowCompanies');
		$this->AddEventPreg('/^fav$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowFavCompanies');

		$this->AddEventPreg('/^(page([1-9]\d{0,5}))?$/i','EventShowCompanies');
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowCompaniesByType');
	}

	/**
	 * Показывает список компаний по рейтингу
	 *
	 */
	protected function EventShowCompanies() {
		$this->sMenuItemSelect='companies';
		$this->sMenuSubItemSelect='all';
		/**
		 * Сортировка
		 */
		$sOrder='company_rating';
		if (getRequest('order')) {
			$sOrder=(string)getRequest('order');
		}
		$sOrderWay='desc';
		if (getRequest('order_way')) {
			$sOrderWay=(string)getRequest('order_way');
		}
		$aOrder = array();
		if ($sOrder!='company_rating' or $sOrderWay!='desc') {
			$aOrder = array('order'=>$sOrder,'order_way'=>$sOrderWay);
		}

		/**
		 * Ограничения
		 */
		$aFilter = array();

		$sUrl = '';
		if (in_array($this->sCurrentEvent, array('my','new','moderation'))){
			$sUrl = $this->sCurrentEvent;
			$this->sMenuSubItemSelect = $this->sCurrentEvent;
			$sPage=$this->GetParam(0);
		}
		if ($this->sCurrentEvent == 'my'){
			if (!$this->oUserCurrent) {
				return parent::EventNotFound();
			}
			$Ids = $this->Blog_GetBlogUsersByUserId($this->oUserCurrent->getId(), array(ModuleBlog::BLOG_USER_ROLE_USER,ModuleBlog::BLOG_USER_ROLE_MODERATOR,ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR), true);
			$Ids = array_merge($this->Blog_GetBlogsByOwnerId($this->oUserCurrent->getId(),true), $Ids);
			$aFilter['blog_id'] = $Ids;
			$aFilter['all'] = 1; // чтобы фильтр показывал все компании, даже не активные
			$sHeader = $this->Lang_Get('plugin.company.companies_my');
		} elseif($this->sCurrentEvent == 'new'){
			$sHeader = $this->Lang_Get('plugin.company.companies_new');
			$aFilter['new_time'] = Config::Get('module.company.new_time');
		} elseif($this->sCurrentEvent == 'moderation'){
			if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
				return parent::EventNotFound();
			}
			$sHeader = $this->Lang_Get('plugin.company.companies_moderation');
			$aFilter['active'] = 0;
		}else{
			$sHeader = $this->Lang_Get('plugin.company.companies');
			$sPage=$this->sCurrentEvent;
		}

		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}

		/**
		 * Получаем список компаний
		 */
		$aResult=$this->PluginCompany_Company_GetCompaniesByFilter($aFilter,array($sOrder=>$sOrderWay),$iPage,Config::Get('module.company.per_page'),array('owner'=>array(),'topic_last'=>array('blog'=>array(),'user'=>array())));
		$aCompany=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').$sUrl,$aOrder);
		/**
		 * Загружаем переменные в шаблон
		 */

		$this->Viewer_Assign('sHeaderName',$sHeader);
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign("aCompany",$aCompany);

		$this->Viewer_Assign("bCompaniesUseOrder",true);
		$this->Viewer_Assign("sCompaniesOrder",htmlspecialchars($sOrder));
		$this->Viewer_Assign("sCompaniesOrderWay",htmlspecialchars($sOrderWay));
		$this->Viewer_Assign("sCompaniesOrderWayNext",htmlspecialchars($sOrderWay=='desc' ? 'asc' : 'desc'));

		$this->Viewer_AddHtmlTitle($sHeader);
		$this->SetTemplateAction('companies');
	}

	/**
	 * Показывает список компаний по типу
	 *
	 * @return unknown
	 */
	protected function EventShowCompaniesByType() {
		$this->sMenuItemSelect='companies';
		$this->sMenuSubItemSelect='all';

		$sType=$this->sCurrentEvent;
		$sPage=$this->GetParam(0);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}
		// если такого типа не существует
		if (!in_array($sType,$this->aTypes)) {
			return parent::EventNotFound();
		}
		/**
		 * Получаем список компаний
		 */
		$aResult=$this->PluginCompany_Company_GetCompaniesByFilter(array('type' => $sType),array(),$iPage,Config::Get('module.company.per_page'));
		$aCompany=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').$sType);
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign("aCompany",$aCompany);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.companies'));
		$this->SetTemplateAction('companies');
	}

	/**
	 * Отображение избранных компаний пользователя
	 *
	 * @return unknown
	 */
	protected function EventShowFavCompanies() {
		$this->sMenuItemSelect='companies';
		$this->sMenuSubItemSelect='fav';
		/**
		 * Проверяем авторизован ли пользователь
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		$sPage=$this->GetParam(0);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}
		/**
		 * Получаем список компаний
		 */
		$aResult=$this->PluginCompany_Company_GetFavouriteCompaniesByUserId($this->oUserCurrent->getId(),$iPage,Config::Get('module.company.per_page'));
		$aCompany=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').'fav');
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign("aCompany",$aCompany);
		$sHeader = $this->Lang_Get('plugin.company.companies_fav');
		$this->Viewer_AddHtmlTitle($sHeader);
		$this->Viewer_Assign('sHeaderName',$sHeader);
		$this->Viewer_Assign("bCompaniesUseOrder",false);
		$this->SetTemplateAction('companies');
	}

	/**
	 * Отображение компаний по стране
	 *
	 * @return unknown
	 */
	protected function EventShowCompaniesByCountry() {
		/**
		 * Страна существует?
		 */
		if (!($oCountry=$this->Geo_GetCountryById($this->getParam(0)))) {
			return parent::EventNotFound();
		}
		/**
		 * Передан ли номер страницы
		 */
		$sPage=$this->GetParam(1);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}

		$aResult=$this->Geo_GetTargets(array('country_id'=>$oCountry->getId(),'target_type'=>'company'),$iPage,Config::Get('module.company.per_page'));
		$aCompanyId=array();
		foreach($aResult['collection'] as $oTarget) {
			$aCompanyId[]=$oTarget->getTargetId();
		}

		$aCompany = $this->PluginCompany_Company_GetCompaniesAdditionalData($aCompanyId);

		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').$this->sCurrentEvent.'/'.$oCountry->getId());
		/**
		 * Загружаем переменные в шаблон
		 */
		if ($aCompany) {
			$this->Viewer_Assign('aPaging',$aPaging);
		}
		$sHeader = $this->Lang_Get('plugin.company.company_companies_header_bycountry').$oCountry->getName();
		$this->Viewer_Assign('sHeaderName',$sHeader);
		$this->Viewer_Assign("aCompany",$aCompany);
		$this->Viewer_AddHtmlTitle($sHeader);
		$this->SetTemplateAction('companies');
	}

	/**
	 * Отображение компаний по городу
	 *
	 * @return unknown
	 */
	protected function EventShowCompaniesByCity() {
		/**
		 * Страна существует?
		 */
		if (!($oCity=$this->Geo_GetCityById($this->getParam(0)))) {
			return parent::EventNotFound();
		}
		/**
		 * Передан ли номер страницы
		 */
		$sPage=$this->GetParam(1);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}

		$aResult=$this->Geo_GetTargets(array('city_id'=>$oCity->getId(),'target_type'=>'company'),$iPage,Config::Get('module.company.per_page'));
		$aCompanyId=array();
		foreach($aResult['collection'] as $oTarget) {
			$aCompanyId[]=$oTarget->getTargetId();
		}

		$aCompany = $this->PluginCompany_Company_GetCompaniesAdditionalData($aCompanyId);

		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').$this->sCurrentEvent.'/'.$oCity->getId());
		/**
		 * Загружаем переменные в шаблон
		 */
		if ($aCompany) {
			$this->Viewer_Assign('aPaging',$aPaging);
		}

		$sHeader = $this->Lang_Get('plugin.company.company_companies_header_bycity').$oCity->getName();
		$this->Viewer_Assign('sHeaderName',$sHeader);
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign("aCompany",$aCompany);
		$this->Viewer_AddHtmlTitle($sHeader);
		$this->SetTemplateAction('companies');
	}

	protected function EventShowCompaniesByTag() {
		/**
		 * Получаем тег из УРЛа
		 */
		$sTag=urldecode($this->getParam(0));

		/**
		 * Передан ли номер страницы
		 */
		$sPage=$this->GetParam(1);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}
		/**
		 * Получаем список компаний
		 */
		$aResult=$this->PluginCompany_Company_GetCompaniesByTag($sTag,$iPage,Config::Get('module.company.per_page'));
		$aCompanies=$aResult['collection'];

		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('companies').'tag/'.htmlspecialchars($sTag));
		// Если используем тэги, а не категории
		if (!Config::Get('module.company.use_category')){
			$aTags=$this->PluginCompany_Company_GetCompanyTags(70);
			$this->Tools_MakeCloud($aTags);
			$this->Viewer_Assign("aTags",$aTags);
		}
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign('aCompany',$aCompanies);
		$this->Viewer_Assign('sTag',$sTag);
		$this->Viewer_AddHtmlTitle($sTag);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_header_tagfind'));
		$this->SetTemplateAction('tags');
	}

	/**
	 * Отображает топики корпоративных блогов
	 *
	 * @return unknown
	 */
	protected function EventShowCorporativeBlogs() {
		$this->sMenuHeadItemSelect='blog';
		$this->Viewer_AddBlock('right','companies',array('plugin'=>'company'));
		$sCompanyUrl=$this->sCurrentEvent;
		$sPage=$this->GetParam(0);
		$this->sMenuItemSelect='companies';

		/**
		 * Передан ли номер страницы
		 */
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}

		$aResult=$this->Topic_GetCorporativeTopics($iPage,Config::Get('module.topic.per_page'));
		$aTopics=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.topic.per_page'),4,Router::GetPath('company').$sCompanyUrl);

		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign('aTopics',$aTopics);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_view_blogs'));
		$this->SetTemplateAction('blogs');
	}

	public function EventShutdown() {

		if ($this->oUserCurrent){
			// Проверяем может ли пользователь добавить компанию, нужно для меню
			$bCanAddCompany=$this->ACL_CanCreateCompany($this->oUserCurrent);
			$this->Viewer_Assign('bCanAddCompany',$bCanAddCompany);
			$this->Viewer_AddBlock('right','companyadd', array('plugin' => 'company'), 110);
			// по сути нужно переделать в функцию, чтобы получать компании которые нельзя показывать, т.е. не активированные.
			$this->Viewer_Assign('iCountFavCompanies',$this->PluginCompany_Company_GetCountFavCompaniesByUser($this->oUserCurrent->getId()));

			//при завершении обновляем значение переменной компаний пользователя
			$this->aUserCompany = $this->PluginCompany_Company_GetCompaniesByUser($this->oUserCurrent->getId(),true);
			$this->Viewer_Assign('aUserCompany',$this->aUserCompany);
			// если только одна компания то выводим прямую ссылку на нее и количество заявок
			if (count($this->aUserCompany) == 1){
				$oUserCompany = reset($this->aUserCompany);
				$this->Viewer_Assign('oUserCompany',$oUserCompany);
				$this->Viewer_Assign('iCountTender',$this->PluginCompany_Company_GetCountTender($oUserCompany));
			}
			if (Config::Get('module.company.use_activate') and $this->oUserCurrent->isAdministrator())
				$this->Viewer_Assign('iCountModeration',$this->PluginCompany_Company_GetCountCompaniesByFilter(array('active' => 0)));
		}
		$this->Viewer_Assign('sMenuHeadItemSelect',$this->sMenuHeadItemSelect);
		$this->Viewer_Assign('sMenuItemSelect',$this->sMenuItemSelect);
		$this->Viewer_Assign('sMenuSubItemSelect',$this->sMenuSubItemSelect);
		$this->Viewer_Assign('sCompanyTemplatePath',$this->getTemplatePathPlugin());
		$this->Viewer_Assign('iCountCompanies',$this->PluginCompany_Company_GetCountCompaniesByFilter());
		$this->Viewer_Assign('iCountNewCompanies',$this->PluginCompany_Company_GetCountCompaniesByFilter(array('new_time' => Config::Get('module.company.new_time'))));

		/**
		 * Подсчитываем новые топики
		 */
		$iCountTopicsCollectiveNew=$this->Topic_GetCountTopicsCollectiveNew();
		$iCountTopicsPersonalNew=$this->Topic_GetCountTopicsPersonalNew();
		$iCountTopicsCompanyNew=$this->Topic_GetCountTopicsCorporativeNew();
		$iCountTopicsNew=$iCountTopicsCollectiveNew+$iCountTopicsPersonalNew+$iCountTopicsCompanyNew;
		$this->Viewer_Assign('iCountTopicsCollectiveNew',$iCountTopicsCollectiveNew);
		$this->Viewer_Assign('iCountTopicsPersonalNew',$iCountTopicsPersonalNew);
		$this->Viewer_Assign('iCountTopicsCompanyNew',$iCountTopicsCompanyNew);
		$this->Viewer_Assign('iCountTopicsNew',$iCountTopicsNew);
	}

}
?>