<?php
/**
 *	Module "Company"
 *	Author: Grebenkin Anton
 *	Contact e-mail: 4freework@gmail.com
 */

class PluginCompany_ActionCompany extends ActionPlugin {
	/**
	 * Главное меню
	 */
	protected $sMenuHeadItemSelect='company';
	/**
	 * Меню
	 */
	protected $sMenuItemSelect='company';
	/**
	 * Субменю
	 */
	protected $sMenuSubItemSelect='all';
	/**
	 * Текущий пользователь
	 */
	protected $oUserCurrent=null;
	protected $aUserCompany=null;
	protected $aBadCompanyUrl = array('new','good','bad','edit','add','admin','vacancies','feedbacks','blog','page','rss','company','test','user','my','fav','ajax','activate','deactivate','settings');
	protected $aTypes;

	/**
	 * Инициализация
	 */
	public function Init() {
		$this->SetDefaultEvent('');
		$this->oUserCurrent = $this->User_GetUserCurrent();
		$this->aTypes = Config::Get('module.company.types');

		/**
		 * Загружаем в шаблон JS текстовки
		 */
		$this->Lang_AddLangJs(array(
			'plugin.company.company_photo_photo_delete','plugin.company.company_photo_mark_as_preview','plugin.company.company_photo_photo_delete_confirm',
			'plugin.company.company_photo_is_preview','plugin.company.company_photo_upload_choose'
		));
	}

	/**
	 * Регистрация событий
	 */
	protected function RegisterEvent() {
		$this->AddEvent('add','EventAddCompany');
		$this->AddEvent('edit','EventEditCompany');
		//$this->AddEvent('admin','EventAdminCompany');
		$this->AddEvent('delete','EventDelete');
		$this->AddEvent('test','EventTest');
		$this->AddEvent('activate','EventActivate');
		$this->AddEvent('deactivate','EventActivate');

		// настройки
		$this->AddEventPreg('/^settings$/i','/^repair$/i','EventSettingsRepair');
		$this->AddEventPreg('/^settings$/i','/^convert$/i','EventSettingsConvert');
		$this->AddEventPreg('/^settings$/i','/^convertgeo$/i','EventSettingsConvertGeo');
		$this->AddEventPreg('/^settings$/i','/^update$/i','EventSettingsUpdate');
		$this->AddEvent('settings','EventSettings');

		//$this->AddEventPreg('/^user$/i','/^[\w\-\_]+$/i','/^feedbacks$/i','/^(page([1-9]\d{0,5}))?$/i','EventShowUserFeedbacks');
		$this->AddEventPreg('/^(page([1-9]\d{0,5}))?$/i','EventShowCompanies');

		$this->AddEventPreg('/^[\w\-\_]+$/i','/^(\d+)\.html$/i', array('EventShowTopic','topic'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^$/i', array('EventShowCompanyProfile','profile'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^blog$/i','/^(\d+)\.html$/i', array('EventShowTopic','topic'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^blog$/', array('EventShowCompanyBlog','blog'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^vacancies$/', array('EventShowCompanyVacancies','vacancies'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^feedbacks$/', array('EventShowCompanyFeedbacks','feedbacks'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^fans$/i','/^(page([1-9]\d{0,5}))?$/i', array('EventShowCompanyFans','fans'));
		$this->AddEventPreg('/^[\w\-\_]+$/i','/^rss$/','RssCompanyBlog');

		$this->AddEventPreg('/^ajax$/i','/^joinleavecompany$/','AjaxCompanyBlogJoinLeave');
		$this->AddEventPreg('/^ajax$/i','/^streamfeedback$/','AjaxStreamFeedback');
		$this->AddEventPreg('/^ajax$/i','/^addfeedback$/','AjaxAddFeedback');
		$this->AddEventPreg('/^ajax$/i','/^responsefeedback$/','AjaxResponseFeedback');
		$this->AddEventPreg('/^ajax$/i','/^feedbackbad$/','AjaxFeedbackBad');
		$this->AddEventPreg('/^ajax$/i','/^votecompany$/','AjaxVoteCompany');
		$this->AddEventPreg('/^ajax$/i','/^favourite$/','AjaxFavouriteCompany');
		$this->AddEventPreg('/^ajax$/i','/^autocompleter$/i','/^tag$/','AjaxAutocompleterTag');
		$this->AddEventPreg('/^ajax$/i','/^autocompleter$/i','/^company$/','AjaxAutocompleterCompany');
		$this->AddEventPreg('/^ajax$/i','/^subscribe-toggle$/','AjaxSubscribeToggle');
		// работа с виджетами
		$this->AddEventPreg('/^ajax$/i','/^update-twitter$/','AjaxUpdateTwitterAccount'); // Сохраняет значения виджета twitter
		$this->AddEventPreg('/^ajax$/i','/^update-fb$/','AjaxUpdateFbAccount'); // Сохраняет значения виджета facebook
		$this->AddEventPreg('/^ajax$/i','/^update-vk$/','AjaxUpdateVkAccount'); // Сохраняет значения виджета вконтакте
		$this->AddEventPreg('/^ajax$/i','/^switch-widget-visible$/','AjaxSwitchWidgetVisible');// Изменяет отображение виджета
		// работа с фото
		$this->AddEventPreg('/^ajax$/i','/^photo-delete$/','AjaxPhotoDelete');// Удаление изображения
		$this->AddEventPreg('/^ajax$/i','/^photo-upload$/','AjaxPhotoUpload'); // Загрузка изображения
		$this->AddEventPreg('/^ajax$/i','/^photo-get-more$/','AjaxPhotoGetMore');// Загрузка изображения на сервер
		$this->AddEventPreg('/^ajax$/i','/^photo-set-description$/','AjaxPhotoSetDescription'); // Установка описания к фото

		$this->AddEventPreg('/^ajax$/i','/^tariff-update$/','AjaxUpdateTariff'); // Обновление тарифа


	}


	/**********************************************************************************
	 ************************ РЕАЛИЗАЦИЯ ЭКШЕНА ***************************************
	 **********************************************************************************
	 */

	/**
	 * Создает новую компанию
	 *
	 * @return unknown
	 */
	protected function EventAddCompany() {
		$this->sMenuSubItemSelect='add';
		$sType = $this->GetParam(0);
		/**
		 * Проверяем авторизован ли пользователь
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Проверяем хватает ли рейтинга пользователю чтобы зарегистрировать компанию
		 */
		if (!$this->ACL_CanCreateCompany($this->oUserCurrent) and !$this->oUserCurrent->isAdministrator()) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_lowrating'),$this->Lang_Get('error'));
			return Router::Action('error');
		}

		$aCountries = $this->Geo_GetCountries(array(),array('sort'=>'asc'),1,300);
		$this->Viewer_Assign('aGeoCountries',$aCountries['collection']);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_add'));

		$aCategories=$this->PluginCompany_Company_GetCompanyTags(30);
		//$aSelected = $this->PluginCompany_Company_GetCompanyTagsByCompanyId($oCompany->getId());
		$this->Viewer_Assign('aCategories',$aCategories);
		$this->Viewer_Assign('aSelected',array());
		/**
		 * Если нажали кнопку "Зарегистрировать"
		 */
		if (isPost('submit_add_company')) {
			$oCompany = Engine::GetEntity('PluginCompany_Company_Company');
			$oCompany->_setValidateScenario('add');
			$oCompany->setOwnerId($this->oUserCurrent->getId());
			$oCompany->setName(getRequest('company_name'));
			if ($sType == '' or !in_array($sType,$this->aTypes))
				$oCompany->setType('base');
			else
				$oCompany->setType($sType);
			/**
			 * Проверяем URL компании, с заменой всех пробельных символов на "_"
			 */
			if (Config::Get('module.company.use_convert_url')){
				$companyUrl = func_translit_url((string)getRequest('company_name'));
			} else{
				$companyUrl = (string)getRequest('company_url');
			}

			$companyUrl=preg_replace("/\s+/",'_',$companyUrl);
			$_REQUEST['company_url']= mb_strtolower($companyUrl);

			$oCompany->setUrl((string)getRequest('company_url'));

			$sText=$this->Text_Parser(getRequest('company_description'));
			$oCompany->setDescription($sText);
			if (!$this->oUserCurrent->isAdministrator() and Config::Get('module.company.use_category') and is_array(getRequest('category')))
				$oCompany->setTags(implode(",", getRequest('category')));
			else
				$oCompany->setTags(getRequest('company_tags'));
			/**
			 * Определяем гео-объект
			 */
			if (getRequest('geo_city')) {
				$oGeoObject=$this->Geo_GetGeoObject('city',getRequest('geo_city'));
			} elseif (getRequest('geo_country')) {
				$oGeoObject=$this->Geo_GetGeoObject('country',getRequest('geo_country'));
			} else {
				$oGeoObject=null;
			}
			// Если вдруг будут ошибки заполняем города и регионы, чтобы не слетали
			if ($oGeoObject) {
				$this->Viewer_Assign('oGeoTarget',$oGeoObject);
				if ($oGeoObject->getCountryId()) {
					$aRegions=$this->Geo_GetRegions(array('country_id'=>$oGeoObject->getCountryId()),array('sort'=>'asc'),1,500);
					$this->Viewer_Assign('aGeoRegions',$aRegions['collection']);
				}
				if ($oGeoObject->getRegionId()) {
					$aCities=$this->Geo_GetCities(array('region_id'=>$oGeoObject->getRegionId()),array('sort'=>'asc'),1,500);
					$this->Viewer_Assign('aGeoCities',$aCities['collection']);
				}
			}

			if ($oGeoObject) {
				if ($oCountry=$oGeoObject->getCountry()) {
					$oCompany->setCountry($oCountry->getName());
				} else {
					$oCompany->setCountry(null);
				}

				if ($oCity=$oGeoObject->getCity()) {
					$oCompany->setCity($oCity->getName());
				} else {
					$oCompany->setCity(null);
				}
			} else {
				$oCompany->setCountry(null);
				$oCompany->setCity(null);
			}
			$oCompany->setDateAdd(date("Y-m-d H:i:s"));


			if (!$this->checkCompanyFields($oCompany)){
				return false;
			}
			/**
			 * Создаём компанию
			 */
			if ($this->PluginCompany_Company_AddCompany($oCompany)) {
				$this->PluginCompany_Company_UpdateCompanyTags($oCompany);
				if ($oGeoObject)
					$this->Geo_CreateTarget($oGeoObject,'company',$oCompany->getId());
				func_header_location(Router::GetPath('company').'edit/'.$oCompany->getId().'/profile/');
			} else {
				$this->Message_AddError($this->Lang_Get('system_error'));
			}
		}


		$this->Viewer_AddBlock('right','companies',array('plugin'=>'company'));
		if ($sType == '' or !in_array($sType,$this->aTypes))
			$this->SetTemplateAction('add');
		else
			$this->SetTemplateAction('add_'.$sType);
	}

	/**
	 * Редактирование компании
	 *
	 * @return unknown
	 */
	protected function EventEditCompany() {
		$sPage=$this->GetParam(1);
		/**
		 * Меню
		 */
		$this->sMenuSubItemSelect='';
		$this->sMenuItemSelect=$sPage;
		/**
		 * Проверям авторизован ли пользователь
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Проверяем передан ли в УРЛе ИД компании
		 */
		$sCompanyId=$this->GetParam(0);
		if (!$oCompany=$this->PluginCompany_Company_GetCompanyById($sCompanyId)) {
			return parent::EventNotFound();
		}


		/**
		 * Явлется ли авторизованный пользователь хозяином компании, либо ее администратором
		 */
		if (!$this->ACL_CanEditCompany($this->oUserCurrent,$oCompany)) {
			return parent::EventNotFound();
		}
		switch ($sPage){
			case 'profile':
				$this->EditCompanyProfile($oCompany);
				break;
			case 'contacts':
				$this->EditCompanyContacts($oCompany);
				break;
			case 'admin':
				$this->EditCompanyAdmin($oCompany);
				break;
			case 'branding':
				$this->EditCompanyBranding($oCompany);
				break;
			case 'widgets':
				$this->EditCompanyWidgets($oCompany);
				break;
			case 'photo':
				$this->EditCompanyPhoto($oCompany);
				break;
			default:
				return parent::EventNotFound();
		}

		$this->Viewer_Assign('oCompany',$oCompany);

		$this->Viewer_AddMenu('company_edit',Plugin::GetTemplatePath('company').'menu.company_edit.tpl');
		$this->Viewer_AddBlock('right','companies',array('plugin'=>'company'));
		$this->Viewer_AddHtmlTitle($oCompany->getName());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_edit'));
	}

	protected function EditCompanyProfile(PluginCompany_ModuleCompany_EntityCompany $oCompany){
		$aStaff = $this->PluginCompany_CompanyStaff_GetCompanyStaffItemsByCompanyId($oCompany->getId(),array('#cache' => array("company_staff_{$oCompany->getId()}",array(""))));
		$aCategories=$this->PluginCompany_Company_GetCompanyTags(30);
		$aSelected = $this->PluginCompany_Company_GetCompanyTagsByCompanyId($oCompany->getId());
		$this->Viewer_Assign('aStaff',$aStaff);
		$this->Viewer_Assign('aCategories',$aCategories);
		$this->Viewer_Assign('aSelected',$aSelected);
		$this->SetTemplateAction('edit');

		if (isPost('submit_edit_company') and $this->FillProfile($oCompany)) {

			if ($this->PluginCompany_Company_UpdateCompany($oCompany)) {
				$this->PluginCompany_Company_UpdateCompanyTags($oCompany);
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_edit_profile'),$this->Lang_Get('attention'));
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'));
			}
		}
	}

	protected function EditCompanyContacts(PluginCompany_ModuleCompany_EntityCompany $oCompany){
		$this->SetTemplateAction('edit_contacts');
		/**
		 * Выбор города и страны
		 */
		$oGeoTarget=$this->Geo_GetTargetByTarget('company',$oCompany->getId());
		$this->Viewer_Assign('oGeoTarget',$oGeoTarget);
		$aCountries=$this->Geo_GetCountries(array(),array('sort'=>'asc'),1,300);
		$this->Viewer_Assign('aGeoCountries',$aCountries['collection']);
		if ($oGeoTarget) {
			if ($oGeoTarget->getCountryId()) {
				$aRegions=$this->Geo_GetRegions(array('country_id'=>$oGeoTarget->getCountryId()),array('sort'=>'asc'),1,500);
				$this->Viewer_Assign('aGeoRegions',$aRegions['collection']);
			}
			if ($oGeoTarget->getRegionId()) {
				$aCities=$this->Geo_GetCities(array('region_id'=>$oGeoTarget->getRegionId()),array('sort'=>'asc'),1,500);
				$this->Viewer_Assign('aGeoCities',$aCities['collection']);
			}
		}


		if (isPost('submit_edit_company') and $this->FillContacts($oCompany)) {
			if ($this->PluginCompany_Company_UpdateCompany($oCompany)) {
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_edit_profile'),$this->Lang_Get('attention'));
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'));
			}
		}
	}

	protected function EditCompanyBranding(PluginCompany_ModuleCompany_EntityCompany $oCompany){
		$this->SetTemplateAction('edit_branding');


		if (isPost('submit_edit_company')) {

			if (isset($_FILES['background']) and is_uploaded_file($_FILES['background']['tmp_name'])) {
				$this->PluginCompany_Content_DeleteBackground($oCompany);
				if (!$this->PluginCompany_Content_UploadBackground($_FILES['background'], $oCompany))
					return false;
			}

			if ($oCompany->getBrandImage() && getRequest('use_branding')){
				$oCompany->setUseBrandImage(1);
			} else{
				$oCompany->setUseBrandImage(0);
			}
			// если цвет введен верно, ставим его если нет, ставим цвет по умолчанию
			if (func_check(getRequest('bg_color'), 'text', 7, 7)) {
				$oCompany->setBackgroundColor(getRequest('bg_color'));
			} else {
				$oCompany->setBackgroundColor('#fbfcfc');
			}

			if ($this->PluginCompany_Company_UpdateCompanyPrefs($oCompany)) {
				func_header_location($oCompany->getUrlFull());
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_edit_profile'),$this->Lang_Get('attention'));
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'));
			}
		}
	}

	protected function EditCompanyWidgets(PluginCompany_ModuleCompany_EntityCompany $oCompany){
		$this->SetTemplateAction('edit_widgets');
		$oCompany->setDateEdit(date("Y-m-d H:i:s"));
		$oCompany->getBrandImage() && getRequest('use_branding') ? $oCompany->setUseBrandImage(1) : $oCompany->setUseBrandImage(0);
		$_REQUEST['screen_name']= $oCompany->getTwitterScreenName();
		$_REQUEST['facebook_url']= $oCompany->getFbUrl();
		$_REQUEST['vk_url']= $oCompany->getVkUrl();
	}

	protected function EditCompanyPhoto(PluginCompany_ModuleCompany_EntityCompany $oCompany){
		$this->SetTemplateAction('edit_photo');
		$_REQUEST['company_id']=$oCompany->getId();
		/**
		 * Проверяем отправлена ли форма с данными(хотяб одна кнопка)
		 */
		if (isPost('submit_edit_company')) {
			$aPhotos = $oCompany->getPhotos();
			if (!($oPhotoMain=$this->PluginCompany_Content_GetCompanyPhotoById(getRequestStr('main_photo')) and $oPhotoMain->getCompanyId()==$oCompany->getId())) {
				if (isset($aPhotos[0])){
					$oPhotoMain=$aPhotos[0];
				}
			}
			if (count($aPhotos)>0)
				$oCompany->setMainPhotoId($oPhotoMain->getId());
			else
				$oCompany->setMainPhotoId(0);
			$oCompany->setPhotoCount(count($aPhotos));
			$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
		} else {
			$_REQUEST['company_id']=$oCompany->getId();
			$_REQUEST['main_photo']=$oCompany->getMainPhotoId();
		}
		$this->Viewer_Assign('aPhotos', $this->PluginCompany_Content_GetPhotosByCompanyId($oCompany->getId()));
	}

	/**
	 * Администрирование компании
	 *
	 * @return unknown
	 */
	protected function EditCompanyAdmin(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$oBlog = $this->Blog_GetBlogById($oCompany->getBlogId());
		/**
		 * Обрабатываем сохранение формы
		 */
		if (isPost('submit_company_admin')) {
			$aUserRank=getRequest('user_rank',array());
			if (!is_array($aUserRank)) {
				$aUserRank=array();
			}
			foreach ($aUserRank as $sUserId => $sRank) {
				if (!($oBlogUser=$this->Blog_GetBlogUserByBlogIdAndUserId($oBlog->getId(),$sUserId))) {
					$this->Message_AddError($this->Lang_Get('system_error'),$this->Lang_Get('error'));
					break;
				}

				switch ($sRank) {
					case 'administrator':
						$oBlogUser->setUserRole(ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR);
						break;
					case 'moderator':
						$oBlogUser->setUserRole(ModuleBlog::BLOG_USER_ROLE_MODERATOR);
						break;
					case 'employee':
						$oBlogUser->setUserRole(ModuleBlog::BLOG_USER_ROLE_USER);
						break;
					case 'reject':
						$this->Talk_SendTalk($this->Lang_Get('plugin.company.company_notice_talk_reject_title'), $this->Lang_Get('plugin.company.company_notice_talk_reject_text').$oCompany->getName()." ".$this->Lang_Get('plugin.company.company_notice_talk_reject_title'),$this->oUserCurrent,$this->User_GetUserById($oBlogUser->getUserId()),false);
						$oBlog->setCountUser($oBlog->getCountUser()-1);
						$this->Blog_DeleteRelationBlogUser($oBlogUser);
						break;
					default:
						$oBlogUser->setUserRole(ModuleBlog::BLOG_USER_ROLE_GUEST);
				}
				$this->Blog_UpdateRelationBlogUser($oBlogUser);
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_edit_users'));
			}
			$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$oCompany->getId()}"));
			$oBlog->setUrl('company_company_'.$oBlog->getUrl());
			$this->Blog_UpdateBlog($oBlog);
		}

		/**
		 * Получаем список подписчиков блога
		 */
		$aBlogUsers=$this->Blog_GetBlogUsersByBlogId(
			$oBlog->getId(),
			array(
				ModuleBlog::BLOG_USER_ROLE_GUEST,
				ModuleBlog::BLOG_USER_ROLE_USER,
				ModuleBlog::BLOG_USER_ROLE_MODERATOR,
				ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR
			)
		);

		$this->Viewer_Assign('oBlog',$oBlog);
		$this->Viewer_Assign('aBlogUsers',$aBlogUsers['collection']);

		$this->Viewer_Assign('BLOG_USER_ROLE_GUEST', ModuleBlog::BLOG_USER_ROLE_GUEST);
		$this->Viewer_Assign('BLOG_USER_ROLE_USER', ModuleBlog::BLOG_USER_ROLE_USER);
		$this->Viewer_Assign('BLOG_USER_ROLE_MODERATOR', ModuleBlog::BLOG_USER_ROLE_MODERATOR);
		$this->Viewer_Assign('BLOG_USER_ROLE_ADMINISTRATOR', ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR);

		if (isPost('submit_company_own')) {
			if ($oBlog->getOwnerId() == $this->oUserCurrent->getId() or $this->oUserCurrent->isAdministrator()){
				$sUsers=getRequest('own_user');
				$aUsers=explode(',',$sUsers);
				//берем первого пользователя
				$sUser=$aUsers[0];
				if ($oUser=$this->User_GetUserByLogin($sUser)){
					$this->PluginCompany_Company_ReplaceCompanyOwner($oBlog, $oUser);
					$this->Cache_Delete("company_{$oCompany->getId()}");
					$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_edit_users_owner'));
					func_header_location($oCompany->getUrlFull());
				} else {
					$this->Message_AddError($this->Lang_Get('talk_create_users_error_not_found').' «'.htmlspecialchars($sUser).'»',$this->Lang_Get('error'));
				}
				$_REQUEST['talk_users']	= $sUser;
				$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$oCompany->getId()}"));
			} else{
				$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			}
		}

		$this->Viewer_AddHtmlTitle($oCompany->getName());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_edit_users'));
		$this->Viewer_Assign('oCompany',$oCompany);
		/**
		 * Устанавливаем шалон для вывода
		 */
		$this->SetTemplateAction('edit_admin');
	}


	/**
	 * Заполняется страница профиля
	 *
	 * @param $oCompany
	 */
	protected function FillProfile(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$oCompany->_setValidateScenario('edit');
		/**
		 * Удалить логотип
		 */
		if (isset($_REQUEST['logo_delete'])) {
			$this->PluginCompany_Content_DeleteLogo($oCompany);
			$oCompany->setLogo(0);
			$oCompany->setLogoType(null);
		}
		/*
		 * Загрузка файла
		 */
		if (is_uploaded_file($_FILES['company_file']['tmp_name'])) {
			$this->PluginCompany_Content_DeleteFile($oCompany);
			$this->PluginCompany_Content_UploadFile($_FILES['company_file'], $oCompany);
		}
		/*
		 * Удаление файла
		 */
		if (isset($_REQUEST['file_delete'])) {
			$this->PluginCompany_Content_DeleteFile($oCompany);
			$oCompany->setFileName(null);
		}

		$oCompany->setName(strip_tags(getRequest('company_name')));
		$oCompany->setLegalName(strip_tags(getRequest('company_name_legal')));
		$oCompany->setDescription(strip_tags(getRequest('company_description')));
		$oCompany->setAboutSource(getRequest('company_about'));
		$oCompany->setAbout($this->Text_Parser(getRequest('company_about')));
		/**
		 * Проверяем дату основания
		 */
		if (func_check(getRequest('company_basis_day'), 'id', 1, 2) and func_check(getRequest('company_basis_month'), 'id', 1, 2) and func_check(getRequest('company_basis_year'), 'id', 4, 4)) {
			$oCompany->setDateBasis(date("Y-m-d H:i:s", mktime(0, 0, 0, getRequest('company_basis_month'), getRequest('company_basis_day'), getRequest('company_basis_year'))));
		} else {
			$oCompany->setDateBasis(null);
		}
		$oCompany->setVacancies($this->Text_Parser(getRequest('company_vacancies')));

		if (!$this->oUserCurrent->isAdministrator() and Config::Get('module.company.use_category') and is_array(getRequest('category')))
			$oCompany->setTags(implode(",", getRequest('category')));
		else
			$oCompany->setTags(getRequest('company_tags'));

		$oCompany->setCountWorkers(getRequest('company_count_workers'));

		// Заполняем руководство
		$this->PluginCompany_CompanyStaff_DeleteStaffByCompanyId($oCompany->getId());
		$aStaffs=getRequest('staff',array());
		foreach ($aStaffs as $oStaff){
			$oStaff = Engine::GetEntity('PluginCompany_ModuleCompanyStaff_EntityCompanyStaff',$oStaff);
			// если данные заполнены не верно, ошибку не выводим и данные не сохраняем.
			if (func_check($oStaff->getStaffName(),'text',2,100) and func_check($oStaff->getStaffPosition(),'text',2,100))
				$oStaff->Add();
		}

		/*
			 * Загрузка логотипа
			 */
		if (isset($_FILES['logo']) and is_uploaded_file($_FILES['logo']['tmp_name'])) {
			$this->PluginCompany_Content_DeleteLogo($oCompany);
			if (!$this->PluginCompany_Content_UploadLogo($_FILES['logo'], $oCompany))
				return false;
		}
		if (!is_array(getRequest('category')) and Config::Get('module.company.use_category') and !$this->oUserCurrent->isAdministrator()){
			$this->Message_AddError($this->Lang_Get('plugin.company.company_error_edit_tags'),$this->Lang_Get('error'));
			return false;
		}
		if (!$this->checkCompanyFields($oCompany)) {
			return false;
		}

		$oCompany->setDateEdit(date("Y-m-d H:i:s"));
		return true;

	}

	/**
	 * Заполняется страница с контактами
	 *
	 * @param $oCompany
	 */
	protected function FillContacts(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$oCompany->_setValidateScenario('contacts');
		$oCompany->setSite(getRequest('company_site'));
		$oCompany->setEmail(getRequest('company_email'));
		$oCompany->setPhone(getRequest('company_phone'));
		$oCompany->setFax(getRequest('company_fax'));
		$oCompany->setSkype(getRequest('company_skype'));
		$oCompany->setIcq(getRequest('company_icq'));
		$oCompany->setContactName(getRequest('company_contact_name'));
		$oCompany->setContactInfo(getRequest('company_contact_info'));
		$oCompany->setLatitude(getRequest('map_marker_latitude'));
		$oCompany->setLongitude(getRequest('map_marker_longitude'));
		$oCompany->setAddress(getRequest('company_address'));
		/**
		 * Определяем гео-объект
		 */
		if (getRequest('geo_city')) {
			$oGeoObject=$this->Geo_GetGeoObject('city',getRequest('geo_city'));
		} elseif (getRequest('geo_country')) {
			$oGeoObject=$this->Geo_GetGeoObject('country',getRequest('geo_country'));
		} else {
			$oGeoObject=null;
		}

		if ($oGeoObject) {
			$this->Geo_CreateTarget($oGeoObject,'company',$oCompany->getId());
			if ($oCountry=$oGeoObject->getCountry()) {
				$oCompany->setCountry($oCountry->getName());
			} else {
				$oCompany->setCountry(null);
			}
			if ($oCity=$oGeoObject->getCity()) {
				$oCompany->setCity($oCity->getName());
			} else {
				$oCompany->setCity(null);
			}
		} else {
			$this->Geo_DeleteTargetsByTarget('company',$oCompany->getId());
			$oCompany->setCountry(null);
			$oCompany->setCity(null);
		}

		if (!$this->checkCompanyFields($oCompany)) {
			return false;
		}

		$oCompany->setDateEdit(date("Y-m-d H:i:s"));
		return true;
	}


	/**
	 * Показать профиль компании
	 * @return unknown
	 */
	protected function EventShowCompanyProfile() {
		$sCompanyUrl=$this->sCurrentEvent;
		$this->sMenuItemSelect='index';
		$this->sMenuSubItemSelect='index';

		/**
		 * Проверяем есть ли компания с таким УРЛ
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}

		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}

		// Получаем данные о сотрудниках компании
		$aCompanyEmpl=$this->Blog_GetBlogUsersByBlogId(
			$oCompany->getBlogId(),
			array(
				ModuleBlog::BLOG_USER_ROLE_USER,
				ModuleBlog::BLOG_USER_ROLE_MODERATOR,
				ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR
			)
		);
		$this->Viewer_Assign('aCompanyEmpl',$aCompanyEmpl['collection']);
		/**
		 * Выставляем SEO данные
		 */
		$sTextSeo=preg_replace("/<.*>/Ui",' ',$oCompany->getDescription());
		$this->Viewer_SetHtmlDescription(func_text_words($sTextSeo,20));
		$this->Viewer_SetHtmlKeywords($oCompany->getTags());
		$aStaff = $this->PluginCompany_CompanyStaff_GetCompanyStaffItemsByCompanyId($oCompany->getId(),array('#cache' => array("company_staff_{$oCompany->getId()}",array(""))));
		$this->Viewer_Assign('aStaff',$aStaff);
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_AddHtmlTitle($oCompany->getName());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_view_profile'));
		$this->CompanyHeaderVariables($oCompany);
		$this->SetTemplateAction('company_profile');
	}

	/**
	 * Отображает блог компании
	 *
	 * @return unknown
	 */
	protected function EventShowCompanyBlog() {
		$sCompanyUrl=$this->sCurrentEvent;
		$sPage=$this->GetParam(1);
		$this->sMenuItemSelect = 'blog';
		$this->sMenuSubItemSelect = 'good';
		$this->sMenuSubCompanyUrl = Router::GetPath('company').$sCompanyUrl;
		/**
		 * Проверяем есть ли компания с таким УРЛ
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}

		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}

		/**
		 * Передан ли номер страницы
		 */
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}
		/**
		 * Получаем список топиков
		 */
		$aResult=$this->Topic_GetTopicsByBlog($oCompany->getBlog(),$iPage,Config::Get('module.topic.per_page'));
		$aTopics=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.topic.per_page'),4,Router::GetPath('company').$sCompanyUrl.'/blog');

		/**
		 * Выставляем SEO данные
		 */
		$sTextSeo=preg_replace("/<.*>/Ui",' ',$oCompany->getDescription());
		$this->Viewer_SetHtmlDescription(func_text_words($sTextSeo,20));
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->CompanyHeaderVariables($oCompany);
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign('aTopics',$aTopics);
		$this->Viewer_Assign('oBlog',$oCompany->getBlog());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_blog_prefix').' '.$oCompany->getName());
		$this->SetTemplateAction('company_blog');
	}

	/**
	 * Отображает вакансии компании
	 *
	 * @return unknown
	 */
	protected function EventShowCompanyVacancies() {
		$sCompanyUrl=$this->sCurrentEvent;
		$this->sMenuItemSelect='vacancies';
		$this->sMenuSubItemSelect='';

		/**
		 * Проверяем есть ли компания с таким УРЛ
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}

		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}

		$aVacancies = array();
		if ($this->PluginCompany_Company_isActivePlugin('job') and Config::Get('module.company.use_jobs')){
			$aResult = $this->PluginJob_Job_GetVacanciesByCompanyId(1,10,$oCompany->getId());
			$aVacancies=$aResult['collection'];
		}
		$this->Viewer_Assign('aVacancies',$aVacancies);

		$this->CompanyHeaderVariables($oCompany);
		$this->Viewer_Assign('sJobTemplatePath',Plugin::GetTemplatePath('job'));
		$this->SetTemplateAction('company_vacancies');
	}


	/**
	 * Отображает отзывы о компании
	 *
	 * @return unknown
	 */
	protected function EventShowCompanyFeedbacks() {
		$sCompanyUrl=$this->sCurrentEvent;
		$this->sMenuItemSelect='feedbacks';

		/**
		 * Проверяем есть ли компания с таким УРЛ
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}

		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		$this->Viewer_AppendScript($this->getTemplatePathPlugin().'js/feedbacks.js');
		$aReturn=$this->Comment_GetCommentsByTargetId($oCompany->getId(),'company');
		$iMaxIdComment=$aReturn['iMaxIdComment'];
		$aComments=$aReturn['comments'];

		$dDate=date("Y-m-d H:i:s");
		if ($this->oUserCurrent) {
			if ($oFeebackRead=$this->PluginCompany_Company_GetFeedbackRead($oCompany->getId(),$this->oUserCurrent->getId())) {
				$dDate=$oFeebackRead->getDateRead();
			}
		}
		$oCompany->setDateRead($dDate);
		/**
		 * Отмечаем дату прочтения отзывов
		 */
		if ($this->oUserCurrent) {
			$oFeebackRead= Engine::GetEntity('PluginCompany_Company_CompanyFeedbackRead');
			$oFeebackRead->setCompanyId($oCompany->getId());
			$oFeebackRead->setUserId($this->oUserCurrent->getId());
			$oFeebackRead->setFeedbackCountLast($oCompany->getCountFeedback());
			$oFeebackRead->setFeedbackIdLast($iMaxIdComment);
			$oFeebackRead->setDateRead(date("Y-m-d H:i:s"));
			$this->PluginCompany_Company_SetFeedbackRead($oFeebackRead);
		}
		$this->Viewer_Assign('aComments',$aComments);
		$this->Viewer_Assign('iMaxIdComment',$iMaxIdComment);
		$this->CompanyHeaderVariables($oCompany);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_feedbacks_title').' '.$oCompany->getName());
		$this->SetTemplateAction('company_feedbacks');
	}

	/**
	 * Отображает фанов компании
	 *
	 * @return unknown
	 */
	protected function EventShowCompanyFans() {
		$sPage=$this->GetParam(1);
		if (preg_match("/^page(\d+)$/i",$sPage,$aMatch)) {
			$iPage=$aMatch[1];
		} else {
			$iPage=1;
		}
		$sCompanyUrl=$this->sCurrentEvent;
		$this->sMenuItemSelect='fans';

		/**
		 * Проверяем есть ли компания с таким УРЛ
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}
		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		$aFansId = $this->PluginCompany_Company_GetFavouriteUsersByTargerId($oCompany->getId(),'company',$iPage,Config::Get('module.company.per_page'));
		$aFans = $this->User_GetUsersAdditionalData($aFansId);
		$aPaging=$this->Viewer_MakePaging($oCompany->getCountFavourite(),$iPage,Config::Get('module.company.per_page'),Config::Get('pagination.pages.count'),Router::GetPath('company').$sCompanyUrl.'/fans');
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign('aFans',$aFans);
		$this->Viewer_AddHtmlTitle($oCompany->getName());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('plugin.company.company_title_view_fans'));
		$this->CompanyHeaderVariables($oCompany);
		$this->SetTemplateAction('company_fans');
	}



	/**
	 * Отображает топик из корпоративного блога
	 *
	 * @return unknown
	 */
	protected function EventShowTopic() {
		$sCompanyUrl=$this->sCurrentEvent;
		$iTopicId=$this->GetParamEventMatch(1,1);
		/**
		 * Меню
		 */
		$this->sMenuItemSelect='blog';
		$this->sMenuSubItemSelect='';
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyByUrl($sCompanyUrl))) {
			return parent::EventNotFound();
		}

		if (!$this->ACL_CanViewCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_not_active'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Проверяем есть ли такой топик
		 */
		if (!($oTopic=$this->Topic_GetTopicById($iTopicId,null,-1))) {
			return parent::EventNotFound();
		}
		/**
		 * Проверяем права на просмотр топика
		 */
		if (!$oTopic->getPublish() and (!$this->oUserCurrent or ($this->oUserCurrent->getId()!=$oTopic->getUserId() and !$this->oUserCurrent->isAdministrator()))) {
			return parent::EventNotFound();
		}

		/**
		 * Обрабатываем добавление коммента
		 */
		$this->SubmitComment($oTopic);
		/**
		 * Достаём комменты к топику
		 */
		$aReturn=$this->Comment_GetCommentsByTargetId($oTopic->getId(),'topic');
		$iMaxIdComment=$aReturn['iMaxIdComment'];
		$aComments=$aReturn['comments'];
		$aCommentsNew=array();
		foreach ($aComments as $oCom) {
			$array=$oCom->_getData();
			$array['obj']=$oCom;
			$aCommentsNew[]=$array;
		}
		/**
		 * Проверяем находится ли топик в избранном у текущего юзера
		 */
		$bInFavourite=false;
		if ($this->oUserCurrent) {
			if ($this->Topic_GetFavouriteTopic($oTopic->getId(),$this->oUserCurrent->getId())) {
				$bInFavourite=true;
			}
		}
		/**
		 * Получаем дату прочтения топика
		 */
		$dDate=date("Y-m-d H:i:s");
		$iCommentLastTopicRead=0;
		if ($this->oUserCurrent) {
			if ($oTopicRead=$this->Topic_GetTopicRead($oTopic->getId(),$this->oUserCurrent->getId())) {
				$dDate=$oTopicRead->getDateRead();
				$iCommentLastTopicRead=$oTopicRead->getCommentIdLast();
			}
		}
		/**
		 * Отмечаем дату прочтения топика
		 */
		if ($this->oUserCurrent) {
			$oTopicRead= Engine::GetEntity('Topic_TopicRead');
			$oTopicRead->setTopicId($oTopic->getId());
			$oTopicRead->setUserId($this->oUserCurrent->getId());
			$oTopicRead->setCommentCountLast($oTopic->getCountComment());
			$oTopicRead->setCommentIdLast($iMaxIdComment);
			$oTopicRead->setDateRead(date("Y-m-d H:i:s"));
			$this->Topic_SetTopicRead($oTopicRead);
		}
		/**
		 * Вызов хуков
		 */
		$this->Hook_Run('topic_show',array("oTopic"=>$oTopic));
		/**
		 * Выставляем SEO данные
		 */
		$sTextSeo=preg_replace("/<.*>/Ui",' ',$oTopic->getText());
		$this->Viewer_SetHtmlDescription(func_text_words($sTextSeo,20));
		$this->Viewer_SetHtmlKeywords($oTopic->getTags());
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->CompanyHeaderVariables($oCompany);
		$this->Viewer_Assign('bInFavourite',$bInFavourite);
		$this->Viewer_Assign('dDateTopicRead',$dDate);
		$this->Viewer_Assign('iCommentLastTopicRead',$iCommentLastTopicRead);
		$this->Viewer_Assign('oTopic',$oTopic);
		$this->Viewer_Assign('aComments',$aComments);
		$this->Viewer_Assign('aCommentsNew',$aCommentsNew);
		$this->Viewer_Assign('iMaxIdComment',$iMaxIdComment);
		$this->Viewer_AddHtmlTitle($oTopic->getBlogTitle());
		$this->Viewer_AddHtmlTitle($oTopic->getTitle());
		$this->SetTemplateAction('topic');
	}

	/**
	 * Cписок компаний по рейтингу
	 *
	 * @return unknown
	 */
	protected function EventShowCompanies() {
		// Обработка этого события перенесена в другой экшн, поэтому туда перенаправляем.
		func_header_location(Router::GetPath('companies'));
	}

	/**
	 * Выводит список отзывов которые написал пользователь
	 *
	 * @return unknown
	 */
	protected function EventShowUserFeedbacks() {
		$this->Viewer_ClearBlocksAll();
		$this->Viewer_AddBlock('right','actions/ActionProfile/sidebar.tpl');
		/**
		 * Получаем логин из УРЛа
		 */
		$sUserLogin=$this->GetParam(0);
		/**
		 * Проверяем есть ли такой юзер
		 */
		if (!($oUserProfile=$this->User_GetUserByLogin($sUserLogin))) {
			return parent::EventNotFound();
		}
		/**
		 * Передан ли номер страницы
		 */
		$iPage=$this->GetParamEventMatch(2,2) ? $this->GetParamEventMatch(2,2) : 1;
		/**
		 * Получаем список комментов
		 */
		$aResult=$this->Comment_GetCommentsByUserId($oUserProfile->getId(),'company',$iPage,Config::Get('module.comment.per_page'));
		$aComments=$aResult['collection'];
		$aPaging=$this->Viewer_MakePaging($aResult['count'],$iPage,Config::Get('module.comment.per_page'),4,Router::GetPath('company').'user/'.$oUserProfile->getLogin().'/feedbacks');

		$iCountFeedbackUser=$this->Comment_GetCountCommentsByUserId($oUserProfile->getId(),'company');
		$this->Viewer_Assign('iCountFeedbackUser',$iCountFeedbackUser);
		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('aPaging',$aPaging);
		$this->Viewer_Assign('aComments',$aComments);
		$this->Viewer_Assign('oUserProfile',$oUserProfile);
		$this->Viewer_AddHtmlTitle($this->Lang_Get('user_menu_publication').' '.$oUserProfile->getLogin());
		$this->Viewer_AddHtmlTitle($this->Lang_Get('user_menu_publication_comment'));
		/**
		 * Устанавливаем шаблон вывода
		 */
		$this->SetTemplateAction('user_feedbacks');
	}

	/**
	 * Удаление компании
	 *
	 * @return unknown
	 */
	protected function EventDelete() {
		/**
		 * Получаем идентификатор компании из УРЛ и проверяем существует ли он
		 */
		$sCompanyId=$this->GetParam(0);
		if (!$oCompany=$this->PluginCompany_Company_GetCompanyById($sCompanyId)) {
			return parent::EventNotFound();
		}

		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		/**
		 * Удаляем компанию
		 */
		$this->PluginCompany_Company_DeleteCompany($oCompany->getId());
		func_header_location(Router::GetPath('company'));
	}

	/**
	 * Активация/деактивация компании
	 *
	 * @return unknown
	 */
	protected function EventActivate() {
		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		/**
		 * Получаем идентификатор компании из УРЛ и проверяем существует ли он
		 */
		$sCompanyId=$this->GetParam(0);
		if (!$oCompany=$this->PluginCompany_Company_GetCompanyById($sCompanyId)) {
			return parent::EventNotFound();
		}
		if ($this->sCurrentEvent == 'activate'){
			$oCompany->setActive(1);
		} else{
			$oCompany->setActive(0);
		}
		$this->PluginCompany_Company_UpdateCompany($oCompany);
		func_header_location($oCompany->getUrlFull());
	}

	/**
	 * Тествое событие, используется для отладки
	 *
	 * @return unknown
	 */
	protected function EventTest() {
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return parent::EventNotFound();
		}
		if (!$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		$this->Cache_Clean();
		$this->SetTemplateAction('test');
	}
	/*
	 * Настройки и админка плагина
	 */
	protected function EventSettings() {
		if (!$this->User_IsAuthorization() or !$this->oUserCurrent->isAdministrator()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return parent::EventNotFound();
		}

		$this->SetTemplateAction('settings');
	}
	/**
	 * Конвертирование базы
	 *
	 * @return unknown
	 */
	protected function EventSettingsConvert() {
		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		if (isPost('submit_convert')) {
			list($bResult,$aErrors) = array_values($this->PluginCompany_Update_Convert());
			if(!$bResult) {
				foreach($aErrors as $sError) $this->Message_AddError($sError,$this->Lang_Get('error'));
			} else{
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.update_success'));
			}
		}
		$this->SetTemplateAction('settings_convert');
	}

	/**
	 * Восстановление битых урл компаний
	 *
	 * @return unknown
	 */
	protected function EventSettingsRepair() {
		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		if (isPost('submit_repair')) {
			if(!$this->PluginCompany_Update_RepairUrl()) {
				$this->Message_AddError($this->Lang_Get('plugin.company.update_error'),$this->Lang_Get('error'));
			} else{
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.update_success'));
			}
		}
		$this->SetTemplateAction('settings_repair');
	}

	/**
	 * Обновление до новой версии
	 *
	 * @return unknown
	 */
	protected function EventSettingsUpdate() {
		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		$sVersion=$this->GetParam(1);
		switch ($sVersion){
			case '0518':
				$this->Viewer_Assign('sHeader',$this->Lang_Get('plugin.company.company_settings_update_plugin_0518'));
				break;
			case '10109':
				$this->Viewer_Assign('sHeader',$this->Lang_Get('plugin.company.company_settings_update_plugin_10109'));
				break;
			case '10110':
				$this->Viewer_Assign('sHeader',$this->Lang_Get('plugin.company.company_settings_update_plugin_10110'));
				break;
		}

		if (isPost('submit_update')) {
			if(!$this->PluginCompany_Update_UpdateToVersion($sVersion)) {
				$this->Message_AddError($this->Lang_Get('plugin.company.update_error'),$this->Lang_Get('error'));
			} else{
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.update_success'));
				$this->Cache_Clean();
			}
		}
		$this->SetTemplateAction('settings_update');
	}

	/**
	 * Конвертация городов и стран в Geo объекты
	 *
	 * @return unknown
	 */
	protected function EventSettingsConvertGeo() {
		if (!$this->oUserCurrent or !$this->oUserCurrent->isAdministrator()) {
			return parent::EventNotFound();
		}
		if (isPost('submit_convert')) {
			if ($this->PluginCompany_Update_ConvertGeo())
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.update_success'));
		}
		$this->SetTemplateAction('settings_convertgeo');
	}


	/**
	 * Обработка добавление комментария к топику
	 *
	 * @param unknown_type $oTopic
	 * @return unknown
	 */
	protected function SubmitComment($oTopic) {
		/**
		 * Если нажали кнопку "Отправить"
		 */
		if (isPost('submit_comment')) {
			$this->Security_ValidateSendForm();
			/**
			 * Проверяем авторизованл ли пользователь
			 */
			if (!$this->oUserCurrent) {
				$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
				return Router::Action('error');
			}
			/**
			 * Проверяем разрешено ли постить комменты
			 */
			if (!$this->ACL_CanPostComment($this->oUserCurrent) and !$this->oUserCurrent->isAdministrator()) {
				$this->Message_AddError($this->Lang_Get('topic_comment_acl'),$this->Lang_Get('error'));
				return false;
			}
			/**
			 * Проверяем разрешено ли постить комменты по времени
			 */
			if (!$this->ACL_CanPostCommentTime($this->oUserCurrent) and !$this->oUserCurrent->isAdministrator()) {
				$this->Message_AddError($this->Lang_Get('topic_comment_limit'),$this->Lang_Get('error'));
				return false;
			}
			/**
			 * Проверяем запрет на добавления коммента автором топика
			 */
			if ($oTopic->getForbidComment()) {
				$this->Message_AddError($this->Lang_Get('topic_comment_notallow'),$this->Lang_Get('error'));
				return false;
			}
			/**
			 * Проверяем текст комментария
			 */
			$sText=$this->Text_Parser(getRequest('comment_text'));
			if (!func_check($sText,'text',2,10000)) {
				$this->Message_AddError($this->Lang_Get('topic_comment_add_text_error'),$this->Lang_Get('error'));
				return false;
			}
			/**
			 * Проверям на какой коммент отвечаем
			 */
			$sParentId=getRequest('reply',0);
			if (!func_check($sParentId,'id')) {
				$this->Message_AddError($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return false;
			}
			$oCommentParent=null;
			if ($sParentId!=0) {
				/**
				 * Проверяем существует ли комментарий на который отвечаем
				 */
				if (!($oCommentParent=$this->Comment_GetCommentById($sParentId))) {
					return false;
				}
				/**
				 * Проверяем из одного топика ли новый коммент и тот на который отвечаем
				 */
				if ($oCommentParent->getTopicId()!=$oTopic->getId()) {
					return false;
				}
			} else {
				/**
				 * Корневой комментарий
				 */
				$sParentId=null;
			}
			/**
			 * Проверка на дублирующий коммент
			 */
			if ($this->Comment_GetCommentUnique($oTopic->getId(),$this->oUserCurrent->getId(),$sParentId,md5($sText))) {
				$this->Message_AddError($this->Lang_Get('topic_comment_spam'),$this->Lang_Get('error'));
				return false;
			}
			/**
			 * Создаём коммент
			 */
			$oCommentNew=new CommentEntity_TopicComment();
			$oCommentNew->setTopicId($oTopic->getId());
			$oCommentNew->setUserId($this->oUserCurrent->getId());
			$oCommentNew->setText($sText);
			$oCommentNew->setDate(date("Y-m-d H:i:s"));
			$oCommentNew->setUserIp(func_getIp());
			$oCommentNew->setPid($sParentId);
			$oCommentNew->setTextHash(md5($sText));
			/**
			 * Добавляем коммент
			 */
			$this->Hook_Run('comment_add_before', array('oCommentNew'=>$oCommentNew,'oCommentParent'=>$oCommentParent,'oTopic'=>$oTopic));
			if ($this->Comment_AddComment($oCommentNew)) {
				$this->Hook_Run('comment_add_after', array('oCommentNew'=>$oCommentNew,'oCommentParent'=>$oCommentParent,'oTopic'=>$oTopic));
				if ($oTopic->getPublish()) {
					/**
					 * Добавляем коммент в прямой эфир если топик не в черновиках
					 */
					$oTopicCommentOnline=new CommentEntity_TopicCommentOnline();
					$oTopicCommentOnline->setTopicId($oCommentNew->getTopicId());
					$oTopicCommentOnline->setCommentId($oCommentNew->getId());
					$this->Comment_AddTopicCommentOnline($oTopicCommentOnline);
				}
				/**
				 * Сохраняем дату последнего коммента для юзера
				 */
				$this->oUserCurrent->setDateCommentLast(date("Y-m-d H:i:s"));
				$this->User_Update($this->oUserCurrent);
				/**
				 * Список емайлов на которые не нужно отправлять уведомление
				 */
				$aExcludeMail=array($this->oUserCurrent->getMail());
				/**
				 * Отправляем уведомление тому на чей коммент ответили
				 */
				if ($oCommentParent and $oCommentParent->getUserId()!=$oTopic->getUserId() and $oCommentNew->getUserId()!=$oCommentParent->getUserId()) {
					$oUserAuthorComment=$oCommentParent->getUser();
					$aExcludeMail[]=$oUserAuthorComment->getMail();
					$this->Notify_SendCommentReplyToAuthorParentComment($oUserAuthorComment,$oTopic,$oCommentNew,$this->oUserCurrent);
				}
				/**
				 * Отправка уведомления автору топика
				 */
				$this->Subscribe_Send('topic_new_comment',$oTopic->getId(),'notify.comment_new.tpl',$this->Lang_Get('notify_subject_comment_new'),array(
					'oTopic' => $oTopic,
					'oComment' => $oCommentNew,
					'oUserComment' => $this->oUserCurrent,
				),$aExcludeMail);
				/**
				 * Добавляем событие в ленту
				 */
				$this->Stream_write($oCommentNew->getUserId(), 'add_comment', $oCommentNew->getId(), $oTopic->getPublish() && $oTopic->getBlog()->getType()!='close');
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return false;
			}
		}
	}


	/**
	 * Проверка полей компании
	 *
	 * @return unknown
	 */
	protected function checkCompanyFields($oCompany=null) {
		$bOk=true;
		if (!$oCompany->_Validate()) {
			foreach($oCompany->_getValidateErrors() as $sFieldKey => $aErrors) {
				foreach ($aErrors as $sError)
					$this->Message_AddError($sError,$this->Lang_Get('error'));
			}
			$bOk=false;
		}

		/**
		 * Проверяем есть ли уже компания с таким наименованием
		 */
		if ($oCompanyExists=$this->PluginCompany_Company_GetCompanyByName(getRequest('company_name'))) {
			if (!$oCompany->getId() or $oCompany->getId()!=$oCompanyExists->getId()) {
				$this->Message_AddError($this->Lang_Get('plugin.company.company_error_add_name_exsist'),$this->Lang_Get('error'));
				$bOk=false;
			}
		}

		/* Проверка URL
		   * Проверка только в том случае если создаём новую компанию, т.к при редактировании URL нельзя менять
		   */
		if (!$oCompany->getId()) {
			/**
			 * Проверяем есть ли уже компания с таким url
			 */
			if ($this->PluginCompany_Company_GetCompanyExist(getRequest('company_url'))) {
				$this->Message_AddError($this->Lang_Get('plugin.company.company_error_add_url_exsist'),$this->Lang_Get('error'));
				$bOk=false;
			}
			/*
			 * Проверяем на допустимую длинну URL
			 */
			if (!func_check(getRequest('company_url'),'login',4,50)) {
				$this->Message_AddError($this->Lang_Get('plugin.company.company_error_add_url_text'),$this->Lang_Get('error'));
				$bOk=false;
			}
			/**
			 * Проверяем на плохие УРЛы
			 */
			if (in_array(getRequest('company_url'),$this->aBadCompanyUrl) or preg_match("/^page(\d+)$/i",getRequest('company_url'),$aMatch) or strpos(getRequest('company_url'),'company') !== false) {
				$this->Message_AddError($this->Lang_Get('plugin.company.company_error_add_url_bad').': '.join(',',$this->aBadCompanyUrl),$this->Lang_Get('error'));
				$bOk=false;
			}
		}
		return $bOk;
	}


	protected function RssCompanyBlog() {
		$sBlogUrl=$this->sCurrentEvent;
		if (!$sBlogUrl or !($oBlog=$this->Blog_GetBlogByUrl('company_'.$sBlogUrl))) {
			return parent::EventNotFound();
		}else{
			$aResult=$this->Topic_GetTopicsByBlog($oBlog,1,Config::Get('module.topic.per_page')*2,'good');
		}
		$aTopics=$aResult['collection'];

		$aChannel['title']=Config::Get('path.root.web');
		$aChannel['link']=Config::Get('path.root.web');
		$aChannel['description']=Config::Get('path.root.web').' / '.$oBlog->getTitle().' / RSS channel';
		$aChannel['language']='ru';
		$aChannel['managingEditor']=Config::Get('general.rss_editor_mail');
		$aChannel['generator']=Config::Get('path.root.web');

		$topics=array();
		foreach ($aTopics as $oTopic){
			$item['title']=$oTopic->getTitle();
			$item['guid']=$oTopic->getUrl();
			$item['link']=$oTopic->getUrl();
			$item['description']=$oTopic->getTextShort();
			$item['pubDate']=$oTopic->getDateAdd();
			$item['author']=$oTopic->getUserLogin();
			$item['category']=htmlspecialchars($oTopic->getTags());
			$topics[]=$item;
		}
		header('Content-Type: application/rss+xml; charset=utf-8');
		$this->Viewer_Assign('aChannel',$aChannel);
		$this->Viewer_Assign('aItems',$topics);
		$this->SetTemplateAction('company_rss');
	}


	/**
	 * Обработка добавление отзыва к компании
	 *
	 * @return bool
	 */
	protected function AjaxAddFeedback() {
		$this->Viewer_SetResponseAjax('json');
		/**
		 * Проверям авторизован ли пользователь
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		/**
		 * Проверяем компанию
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById(getRequest('cmt_target_id')))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		/**
		 * Проверяем разрешено ли постить отзывы
		 */
		if (!$this->ACL_CanPostFeedback($this->oUserCurrent) and !$this->oUserCurrent->isAdministrator()) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_feedback_acl'),$this->Lang_Get('error'));
			return;
		}

		/**
		 * Проверяем текст отзыва
		 */
		$sText=$this->Text_Parser(getRequest('comment_text'));
		if (!func_check($sText,'text',2,3000)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_feedback_add_text_error'),$this->Lang_Get('error'));
			return;
		}
		/**
		 * Проверям на какой отзыв отвечаем
		 */
		$sParentId=(int)getRequest('reply');
		if (!func_check($sParentId,'id')) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}
		$oCommentParent=null;
		if ($sParentId!=0) {
			/**
			 * Проверяем существует ли отзыв на который отвечаем
			 */
			if (!($oCommentParent=$this->Comment_GetCommentById($sParentId))) {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return;
			}
			/**
			 * Проверяем из одной ли компании новый отзыв и тот на который отвечаем
			 */
			if ($oCommentParent->getTargetId()!=$oCompany->getId()) {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return;
			}
		} else {
			/**
			 * Корневой отзыв
			 */
			$sParentId=null;
		}
		/**
		 * Проверка на дублирующий отзыв
		 */
		if ($this->Comment_GetCommentUnique($oCompany->getId(),'company',$this->oUserCurrent->getId(),$sParentId,md5($sText))) {
			$this->Message_AddErrorSingle($this->Lang_Get('topic_comment_spam'),$this->Lang_Get('error'));
			return;
		}
		/**
		 * Создаём отзыв
		 */
		$oCommentNew = Engine::GetEntity('Comment');
		$oCommentNew->setTargetId($oCompany->getId());
		$oCommentNew->setTargetType('company');
		$oCommentNew->setTargetParentId($oCompany->getBlogId());
		$oCommentNew->setUserId($this->oUserCurrent->getId());
		$oCommentNew->setText($sText);
		$oCommentNew->setDate(date("Y-m-d H:i:s"));
		$oCommentNew->setUserIp(func_getIp());
		$oCommentNew->setPid($sParentId);
		$oCommentNew->setTextHash(md5($sText));
		$oCommentNew->setPublish(1);

		/**
		 * Добавляем отзыв
		 */
		//$this->Hook_Run('feedback_add_before', array('oCommentNew'=>$oCommentNew,'oCommentParent'=>$oCommentParent,'oCompany'=>$oCompany));
		if ($this->Comment_AddComment($oCommentNew)) {
			//$this->Hook_Run('feedback_add_after', array('oCommentNew'=>$oCommentNew,'oCommentParent'=>$oCommentParent,'oCompany'=>$oCompany));
			$this->PluginCompany_Company_increaseCompanyCountFeedbacks($oCompany->getId());
			$this->Viewer_AssignAjax('sCommentId',$oCommentNew->getId());

			//if ($oTopic->getActive()) {
			// Добавляем отзыв в прямой эфир если компания активна
			$oCommentOnline=Engine::GetEntity('Comment_CommentOnline');
			$oCommentOnline->setTargetId($oCommentNew->getTargetId());
			$oCommentOnline->setTargetType($oCommentNew->getTargetType());
			$oCommentOnline->setTargetParentId($oCompany->getBlogId());
			$oCommentOnline->setCommentId($oCommentNew->getId());

			$this->Comment_AddCommentOnline($oCommentOnline);

			/**
			 * Отправка уведомления подписанным на новые отзывы
			 */
			$aExcludeMail=array($this->oUserCurrent->getMail());
			$this->Subscribe_Send('company_new_feedback', $oCompany->getId(), 'notify.company_new_feedback.tpl', $this->Lang_Get('plugin.company.notify_subject_feedback_new').' '.$oCompany->getName(), array(
				'oComment' => $oCommentNew,
				'oCompany' => $oCompany,
				'oUserComment' => $this->oUserCurrent,
			), $aExcludeMail,'PluginCompany');
			//}
			/**
			 * Сохраняем дату последнего коммента для юзера
			 */
			$this->oUserCurrent->setDateCommentLast(date("Y-m-d H:i:s"));
			$this->User_Update($this->oUserCurrent);
		} else {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
		}
	}


	/**
	 * Автоподставновка тегов (видов деятельности)
	 *
	 */
	protected function AjaxAutocompleterTag() {
		$this->Viewer_SetResponseAjax('json');
		if (!($sValue=getRequest('value',null,'post'))) {
			return ;
		}

		$aItems=array();
		$aTags=$this->PluginCompany_Company_GetCompanyTagsByLike($sValue,10);
		foreach ($aTags as $oTag) {
			$aItems[]=$oTag->getText();
		}
		$this->Viewer_AssignAjax('aItems',$aItems);
	}

	protected function AjaxAutocompleterCompany() {
		$this->Viewer_SetResponseAjax('json');
		if (!($sValue=getRequest('value',null,'post'))) {
			return ;
		}
		$aItems=array();
		$aCompanies=$this->PluginCompany_Company_GetCompaniesByFilter(array('name_like' => $sValue),array(),1,10,array());
		foreach ($aCompanies['collection'] as $oCompany) {
			$oCompany->setLogo($oCompany->getLogoPath(24));
			$aItems[]=$oCompany->_getData();
		}
		$this->Viewer_AssignAjax('aItems',$aItems);
	}

	/**
	 * Обработка входа\выхода из компании
	 *
	 */
	protected function AjaxCompanyBlogJoinLeave() {
		$this->Viewer_SetResponseAjax('json');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}

		$idBlog=getRequest('idBlog',null,'post');
		if (!($oBlog=$this->Blog_GetBlogById($idBlog))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!in_array($oBlog->getType(),array('company'))) {
			$this->Message_AddErrorSingle($this->Lang_Get('blog_join_error_invite'),$this->Lang_Get('error'));
			return;
		}

		$oBlogUser=$this->Blog_GetBlogUserByBlogIdAndUserId($oBlog->getId(),$this->oUserCurrent->getId());
		if (!$oBlogUser) {
			if ($oBlog->getOwnerId()!=$this->oUserCurrent->getId()) {
				/**
				 * Присоединяем юзера к блогу
				 */
				$bResult=false;
				if($oBlogUser) {
					$oBlogUser->setUserRole(ModuleBlog::BLOG_USER_ROLE_GUEST);
					$bResult = $this->Blog_UpdateRelationBlogUser($oBlogUser);
				} elseif($oBlog->getType()=='company') {
					$oBlogUserNew=Engine::GetEntity('Blog_BlogUser');
					$oBlogUserNew->setBlogId($oBlog->getId());
					$oBlogUserNew->setUserId($this->oUserCurrent->getId());
					$oBlogUserNew->setUserRole(ModuleBlog::BLOG_USER_ROLE_GUEST);
					$bResult = $this->Blog_AddRelationBlogUser($oBlogUserNew);
				}
				if ($bResult) {
					$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_join'),$this->Lang_Get('attention'));
					$this->Viewer_AssignAjax('bState',true);
					/**
					 * Увеличиваем число читателей блога
					 */
					$oBlog->setCountUser($oBlog->getCountUser()+1);
					$oBlog->setUrl('company_company_'.$oBlog->getUrl());
					$this->Blog_UpdateBlog($oBlog);
					$this->Viewer_AssignAjax('iCountUser',$oBlog->getCountUser());
					/**
					 * Добавляем событие в ленту
					 */
					$this->Stream_write($this->oUserCurrent->getId(), 'join_blog', $oBlog->getId());
				} else {
					$sMsg=($oBlog->getType()=='close')
						? $this->Lang_Get('blog_join_error_invite')
						: $this->Lang_Get('system_error');
					$this->Message_AddErrorSingle($sMsg,$this->Lang_Get('error'));
					return;
				}
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_notice_join_owner'),$this->Lang_Get('attention'));
				return;
			}
		}
		if ($oBlogUser) {
			/**
			 * Покидаем блог
			 */
			if ($this->Blog_DeleteRelationBlogUser($oBlogUser)) {
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_leave'),$this->Lang_Get('attention'));
				$this->Viewer_AssignAjax('bState',false);
				/**
				 * Уменьшаем число читателей блога
				 */
				$oBlog->setCountUser($oBlog->getCountUser()-1);
				$oBlog->setUrl('company_company_'.$oBlog->getUrl());
				$this->Blog_UpdateBlog($oBlog);
				$this->Viewer_AssignAjax('iCountUser',$oBlog->getCountUser());

			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return;
			}
		}
	}

	/**
	 * Обработка получения последних отзывов
	 *
	 */
	protected function AjaxStreamFeedback() {
		$this->Viewer_SetResponseAjax('json');
		if ($aComments=$this->Comment_GetCommentsOnline('company',Config::Get('block.stream.row'))) {
			$oViewer=$this->Viewer_GetLocalViewer();
			$oViewer->Assign('aComments',$aComments);
			$sTextResult=$oViewer->Fetch(Plugin::GetTemplatePath(__CLASS__)."blocks/block.stream_feedback.tpl");
			$this->Viewer_AssignAjax('sText',$sTextResult);
		} else {
			$this->Message_AddErrorSingle($this->Lang_Get('block_stream_feedbacks_no'),$this->Lang_Get('attention'));
			return;
		}
	}

	/**
	 * Получение новых отзывов
	 *
	 */
	protected function AjaxResponseFeedback() {
		$this->Viewer_SetResponseAjax('json');

		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}

		$idTopic=getRequest('idTarget',null,'post');
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idTopic))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		$idCommentLast=getRequest('idCommentLast',null,'post');
		$selfIdComment=getRequest('selfIdComment',null,'post');
		$aComments=array();

		if (getRequest('bUsePaging',null,'post') and $selfIdComment) {
			if ($oComment=$this->Comment_GetCommentById($selfIdComment) and $oComment->getTargetId()==$oCompany->getId() and $oComment->getTargetType()=='company') {
				$oViewerLocal=$this->Viewer_GetLocalViewer();
				$oViewerLocal->Assign('oUserCurrent',$this->oUserCurrent);
				$oViewerLocal->Assign('bOneComment',true);

				$oViewerLocal->Assign('oComment',$oComment);
				$sText=$oViewerLocal->Fetch(Plugin::GetTemplatePath('company')."feedback.tpl");
				$aCmt=array();
				$aCmt[]=array(
					'html' => $sText,
					'obj'  => $oComment,
				);
			} else {
				$aCmt=array();
			}
			$aReturn['comments']=$aCmt;
			$aReturn['iMaxIdComment']=$selfIdComment;
		} else {
			$aReturn=$this->Comment_GetCommentsNewByTargetId($oCompany->getId(),'company',$idCommentLast);
		}
		$iMaxIdComment=$aReturn['iMaxIdComment'];

		$oFeebackRead= Engine::GetEntity('PluginCompany_Company_CompanyFeedbackRead');
		$oFeebackRead->setCompanyId($oCompany->getId());
		$oFeebackRead->setUserId($this->oUserCurrent->getId());
		$oFeebackRead->setFeedbackCountLast($oCompany->getCountFeedback());
		$oFeebackRead->setFeedbackIdLast($iMaxIdComment);
		$oFeebackRead->setDateRead(date("Y-m-d H:i:s"));
		$this->PluginCompany_Company_SetFeedbackRead($oFeebackRead);

		$aCmts=$aReturn['comments'];
		if ($aCmts and is_array($aCmts)) {
			foreach ($aCmts as $aCmt) {
				$aComments[]=array(
					'html' => $aCmt['html'],
					'idParent' => $aCmt['obj']->getPid(),
					'id' => $aCmt['obj']->getId(),
				);
			}
		}

		$this->Viewer_AssignAjax('iMaxIdComment',$iMaxIdComment);
		$this->Viewer_AssignAjax('aComments',$aComments);
	}

	/**
	 * Скрытие отзыва
	 *
	 */
	protected function AjaxFeedbackBad() {
		$this->Viewer_SetResponseAjax('json');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		$idComment = getRequest('idComment',null,'post');
		if ($oComment = $this->Comment_GetCommentById($idComment)) {
			$oCompany = $this->PluginCompany_Company_GetCompanyById($oComment->getTargetId());
			$oBlog = $oCompany->getBlog();
			if ($oBlog->getUserIsAdministrator() or $oBlog->getUserIsModerator() or $this->oUserCurrent->isAdministrator()) {
				($oComment->getRating() == 0 ? $oComment->setRating(-100) : $oComment->setRating(0));
				if ($this->Comment_UpdateCommentRating($oComment)) {
					$bState=(bool)$oComment->isBad();
					if ($bState) {
						$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_feedback_colapce'),$this->Lang_Get('attention'));
						$this->Viewer_AssignAjax('bState',$bState);
						$this->Viewer_AssignAjax('sTextToggle',$this->Lang_Get('plugin.company.feedback_show'));
					} else {
						$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_notice_feedback_expand'),$this->Lang_Get('attention'));
						$this->Viewer_AssignAjax('bState',$bState);
						$this->Viewer_AssignAjax('sTextToggle',$this->Lang_Get('plugin.company.feedback_hide'));
					}
				} else {
					$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_feedback_edit'),$this->Lang_Get('error'));
					return;
				}
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
				return;
			}
		} else {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_error_feedback_notfound'),$this->Lang_Get('error'));
			return;
		}
		// Чистим кэши
		if(Config::Get('sys.cache.solid')){
			$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array("comment_update"));
		}
		$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array("comment_update_status_company"));
	}

	/**
	 * Голосование за компанию
	 *
	 */
	protected function AjaxVoteCompany() {
		$this->Viewer_SetResponseAjax('json');
		$idCompany = getRequest('idCompany',null,'post');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}

		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if ($oCompany->getOwnerId()==$this->oUserCurrent->getId()) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_notice_voted_owner'),$this->Lang_Get('attention'));
			return;
		}

		if ($oCompanyVote=$this->Vote_GetVote($oCompany->getId(),'company',$this->oUserCurrent->getId())) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_notice_voted'),$this->Lang_Get('attention'));
			return;
		}

		$iValue=getRequest('value',null,'post');
		if (!in_array($iValue,array('1','-1','0'))) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_vote_values'),$this->Lang_Get('attention'));
			return;
		}

		if (!$this->ACL_CanVoteCompany($this->oUserCurrent,$oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_vote_acl'),$this->Lang_Get('attention'));
			return;
		}
		$oCompanyVote=Engine::GetEntity('Vote');
		$oCompanyVote->setTargetId($oCompany->getId());
		$oCompanyVote->setTargetType('company');
		$oCompanyVote->setVoterId($this->oUserCurrent->getId());
		$oCompanyVote->setDirection($iValue);
		$oCompanyVote->setDate(date("Y-m-d H:i:s"));

		$iVal=0;
		if ($iValue!=0) {
			$iVal=(float)$this->PluginCompany_Company_VoteCompany($this->oUserCurrent,$oCompany,$iValue);
		}
		$oCompanyVote->setValue($iVal);
		$oCompany->setCountVote($oCompany->getCountVote()+1);

		if ($this->Vote_AddVote($oCompanyVote) and $this->PluginCompany_Company_UpdateCompany($oCompany)) {
			if ($iValue)
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_vote_ok'),$this->Lang_Get('attention'));

			$this->Viewer_AssignAjax('iRating',$oCompany->getRating());
			$this->Viewer_AssignAjax('iCountVote',$oCompany->getCountVote());

			//$this->Stream_write($oTopicVote->getVoterId(), 'vote_topic', $oTopic->getId());
		} else {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_vote_after'),$this->Lang_Get('error'));
			return;
		}
	}

	/**
	 * Обработка избранного - компаний
	 *
	 */
	protected function AjaxFavouriteCompany() {
		$this->Viewer_SetResponseAjax('json');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}

		$iType=getRequest('type',null,'post');
		if (!in_array($iType,array('1','0'))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById(getRequest('idCompany',null,'post')))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		$oFavouriteCompany=$this->Favourite_GetFavourite($oCompany->getId(),'company',$this->oUserCurrent->getId());
		if (!$oFavouriteCompany and $iType) {
			$oFavouriteCompanyNew=Engine::GetEntity('Favourite',
				array(
					'target_id'      => $oCompany->getId(),
					'user_id'        => $this->oUserCurrent->getId(),
					'target_type'    => 'company',
					'target_publish' => '1'
				)
			);
			$oCompany->setCountFavourite($oCompany->getCountFavourite()+1);
			if ($this->Favourite_AddFavourite($oFavouriteCompanyNew) and $this->PluginCompany_Company_UpdateCompany($oCompany)) {
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_favourite_add_ok'),$this->Lang_Get('attention'));
				$this->Viewer_AssignAjax('bState',true);
				$this->Viewer_AssignAjax('iCount', $oCompany->getCountFavourite());
				$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array("favourite_company_change"));
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return;
			}
		}
		if (!$oFavouriteCompany and !$iType) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_favourite_add_no'),$this->Lang_Get('error'));
			return;
		}
		if ($oFavouriteCompany and $iType) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.company_favourite_add_already'),$this->Lang_Get('error'));
			return;
		}
		if ($oFavouriteCompany and !$iType) {
			$oCompany->setCountFavourite($oCompany->getCountFavourite()-1);
			if ($this->Favourite_DeleteFavourite($oFavouriteCompany) and $this->PluginCompany_Company_UpdateCompany($oCompany)) {
				$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.company_favourite_del_ok'),$this->Lang_Get('attention'));
				$this->Viewer_AssignAjax('bState',false);
				$this->Viewer_AssignAjax('iCount', $oCompany->getCountFavourite());
				$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array("favourite_company_change"));
			} else {
				$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
				return;
			}
		}
	}

	/**
	 * Обработка увеличения/уменьшения числа подписчиков компании
	 *
	 */
	protected function AjaxSubscribeToggle() {
		$this->Viewer_SetResponseAjax('json');
		$iValue=getRequest('iValue',null,'post');
		$idCompany=getRequest('idCompany',null,'post');
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}
		// если подписывается увеличиваем число подписчиков
		if ($iValue ==1)
			$this->PluginCompany_Company_increaseCompanyCountSubscribe($oCompany->getId());
		else
			$this->PluginCompany_Company_decreaseCompanyCountSubscribe($oCompany->getId());
	}


	protected function AjaxUpdateTwitterAccount() {
		$this->Viewer_SetResponseAjax('json');
		$screenName = getRequest('screenName',null,'post');
		$idCompany = getRequest('idCompany',null,'post');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!$this->ACL_CanEditCompany($this->oUserCurrent, $oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('attention'));
			return;
		}
		if ($screenName == '') {
			$oCompany->setTwitterScreenName('');
			$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
			$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
			return;
		}

		if (!$this->PluginCompany_Company_CheckAndSaveTwitterAccount($oCompany, $screenName)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.widget_error_value'),$this->Lang_Get('error'));
			return;
		}
		$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
	}

	protected function AjaxUpdateFbAccount() {
		$this->Viewer_SetResponseAjax('json');
		$fbUrl = getRequest('fbUrl',null,'post');
		$idCompany = getRequest('idCompany',null,'post');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!$this->ACL_CanEditCompany($this->oUserCurrent, $oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('attention'));
			return;
		}

		if ($fbUrl == '') {
			$oCompany->setFbUrl('');
			$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
			$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
			return;
		}

		if (!$this->PluginCompany_Company_CheckAndSaveFBAccount($oCompany,$fbUrl)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.widget_error_value'),$this->Lang_Get('error'));
			return;
		}
		$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
	}

	protected function AjaxUpdateVkAccount() {
		$this->Viewer_SetResponseAjax('json');
		$vkUrl = getRequest('vkUrl',null,'post');
		$idCompany = getRequest('idCompany',null,'post');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!$this->ACL_CanEditCompany($this->oUserCurrent, $oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('attention'));
			return;
		}

		if ($vkUrl == '') {
			$oCompany->setVkUrl('');
			$oCompany->setVkId('');
			$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
			$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
			return;
		}

		if (!$this->PluginCompany_Company_CheckAndSaveVkAccount($oCompany,$vkUrl)) {
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.widget_error_value'),$this->Lang_Get('error'));
			return;
		}
		$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_ok'),$this->Lang_Get('attention'));
	}

	protected function AjaxSwitchWidgetVisible(){
		$this->Viewer_SetResponseAjax('json');
		if (!getRequest('widgetName')) {
			$this->Message_AddError($this->Lang_Get('system_error'),$this->Lang_Get('error'));
		}

		$widgetName = getRequest('widgetName',null,'post');
		$idCompany = getRequest('idCompany',null,'post');
		$iVisible = getRequest('iVisible',null,'post');
		if (!$this->oUserCurrent) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!$this->ACL_CanEditCompany($this->oUserCurrent, $oCompany)) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('attention'));
			return;
		}

		if (!in_array($widgetName,array('twitter','fb','vk'))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('attention'));
			return;
		}
		$oCompany->setWidgetVisible($widgetName,$iVisible);
		if (!$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany)){
			$this->Message_AddErrorSingle($this->Lang_Get('plugin.company.widget_error_visible'),$this->Lang_Get('error'));
			return;
		}
		$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.widget_notice_visible_ok'),$this->Lang_Get('attention'));


	}


	/**
	 * AJAX подгрузка следующих фото
	 *
	 */
	protected function AjaxPhotoGetMore() {
		/**
		 * Устанавливаем формат Ajax ответа
		 */
		$this->Viewer_SetResponseAjax('json');
		/**
		 * Существует ли топик
		 */
		$oCompany = $this->PluginCompany_Company_GetCompanyById(getRequestStr('company_id'));
		if (!$oCompany || !getRequest('last_id')) {
			$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
			return false;
		}
		/**
		 * Получаем список фото
		 */
		$aPhotos = $oCompany->getPhotos(getRequestStr('last_id'), Config::Get('module.company.photo.per_page'));
		$aResult = array();
		if (count($aPhotos)) {
			/**
			 * Формируем данные для ajax ответа
			 */
			foreach($aPhotos as $oPhoto) {
				$aResult[] = array('id' => $oPhoto->getId(), 'path_thumb' => $oPhoto->getWebPath('50crop'), 'path' => $oPhoto->getWebPath(), 'description' => $oPhoto->getDescription());
			}
			$this->Viewer_AssignAjax('photos', $aResult);
		}
		$this->Viewer_AssignAjax('bHaveNext', count($aPhotos)==Config::Get('module.company.photo.per_page'));
	}
	/**
	 * AJAX удаление фото
	 *
	 */
	protected function AjaxPhotoDelete() {
		/**
		 * Устанавливаем формат Ajax ответа
		 */
		$this->Viewer_SetResponseAjax('json');
		/**
		 * Проверяем авторизован ли юзер
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Поиск фото по id
		 */
		$oPhoto = $this->PluginCompany_Content_GetCompanyPhotoById(getRequestStr('id'));
		if ($oPhoto) {
			if ($oPhoto->getCompanyId()) {
				/**
				 * Проверяем права на топик
				 */
				$oCompany=$this->PluginCompany_Company_GetCompanyById($oPhoto->getCompanyId());
				if ($oCompany and $this->ACL_CanEditCompany($this->oUserCurrent,$oCompany)) {
					//if ($oCompany->getPhotoCount()>1) {
						$this->PluginCompany_Content_DeleteCompanyPhoto($oPhoto);
						/**
						 * Если удаляем главную фотку топика, то её необходимо сменить
						 */
						if ($oPhoto->getId()==$oCompany->getPMainPhotoId()) {
							$aPhotos = $oCompany->getPhotos(0,1);
							if ($oCompany->getPhotoCount() == 1)
								$oCompany->setMainPhotoId(0);
							else
								$oCompany->setMainPhotoId($aPhotos[0]->getId());
						}
						$oCompany->setPhotoCount($oCompany->getPhotoCount()-1);
						$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
						$this->Message_AddNotice($this->Lang_Get('plugin.company.company_photo_photo_deleted'), $this->Lang_Get('attention'));
					//} else {
					//	$this->Message_AddError($this->Lang_Get('plugin.company.company_photo_photo_deleted_error_last'), $this->Lang_Get('error'));
					//}
					return;
				}
			} else {
				$this->PluginCompany_Content_DeleteCompanyPhoto($oPhoto);
				$this->Message_AddNotice($this->Lang_Get('plugin.company.company_photo_photo_deleted'), $this->Lang_Get('attention'));
				return;
			}
		}
		$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
	}
	/**
	 * AJAX установка описания фото
	 *
	 */
	protected function AjaxPhotoSetDescription() {
		/**
		 * Устанавливаем формат Ajax ответа
		 */
		$this->Viewer_SetResponseAjax('json');
		/**
		 * Проверяем авторизован ли юзер
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Поиск фото по id
		 */
		$oPhoto = $this->PluginCompany_Content_GetCompanyPhotoById(getRequestStr('id'));
		if ($oPhoto) {
			if ($oPhoto->getCompanyId()) {
				// проверяем права на топик
				if ($oCompany=$this->PluginCompany_Company_GetCompanyById($oPhoto->getCompanyId()) and $this->ACL_CanEditCompany($this->oUserCurrent,$oCompany)) {
					$oPhoto->setDescription(htmlspecialchars(strip_tags(getRequestStr('text'))));
					$this->PluginCompany_Content_UpdateCompanyPhoto($oPhoto);
				}
			} else {
				$oPhoto->setDescription(htmlspecialchars(strip_tags(getRequestStr('text'))));
				$this->PluginCompany_Content_UpdateCompanyPhoto($oPhoto);
			}
		}
	}


	/**
	 * AJAX загрузка фоток
	 *
	 * @return unknown
	 */
	protected function AjaxPhotoUpload() {
		/**
		 * Устанавливаем формат Ajax ответа
		 * В зависимости от типа загрузчика устанавливается тип ответа
		 */
		if (getRequest('is_iframe')) {
			$this->Viewer_SetResponseAjax('jsonIframe', false);
		} else {
			$this->Viewer_SetResponseAjax('json');
		}
		/**
		 * Проверяем авторизован ли юзер
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('not_access'),$this->Lang_Get('error'));
			return Router::Action('error');
		}
		/**
		 * Файл был загружен?
		 */
		if (!isset($_FILES['Filedata']['tmp_name'])) {
			$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
			return false;
		}

		$iCompanyId = getRequestStr('company_id');
		$sTargetId = null;
		$iCountPhotos = 0;
		// Если от сервера не пришёл id компании, то пытаемся определить временный код для новой компании. Если и его нет. то это ошибка
		if (!$iCompanyId) {
			$sTargetId = empty($_COOKIE['ls_photo_target_tmp']) ? getRequestStr('ls_photo_target_tmp') : $_COOKIE['ls_photo_target_tmp'];
			if (!$sTargetId) {
				$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
				return false;
			}
			$iCountPhotos = $this->PluginCompany_Content_GetCountPhotosByTargetTmp($sTargetId);
		} else {
			/**
			 * Загрузка фото к уже существующему топику
			 */
			$oCompany = $this->PluginCompany_Company_GetCompanyById($iCompanyId);
			if (!$oCompany or !$this->ACL_CanEditCompany($this->oUserCurrent,$oCompany)) {
				$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
				return false;
			}
			$iCountPhotos = $this->PluginCompany_Content_GetCountPhotosByCompanyId($iCompanyId);
		}
		/**
		 * Максимальное количество фото в топике
		 */
		if ($iCountPhotos >= Config::Get('module.company.photo.count_photos_max')) {
			$this->Message_AddError($this->Lang_Get('plugin.company.company_photo_error_too_much_photos', array('MAX' => Config::Get('module.company.photo.count_photos_max'))), $this->Lang_Get('error'));
			return false;
		}
		/**
		 * Максимальный размер фото
		 */
		if (filesize($_FILES['Filedata']['tmp_name']) > Config::Get('module.company.photo.photo_max_size')*1024) {
			$this->Message_AddError($this->Lang_Get('plugin.company.company_photo_error_bad_filesize', array('MAX' => Config::Get('module.company.photo.photo_max_size'))), $this->Lang_Get('error'));
			return false;
		}
		/**
		 * Загружаем файл
		 */
		$sFile = $this->PluginCompany_Content_UploadCompanyPhoto($_FILES['Filedata']);
		if ($sFile) {
			/**
			 * Создаем фото
			 */
			$oPhoto = Engine::GetEntity('PluginCompany_ModuleContent_EntityPhoto');
			$oPhoto->setPath($sFile);
			if ($iCompanyId) {
				$oPhoto->setCompanyId($iCompanyId);
			} else {
				$oPhoto->setTargetTmp($sTargetId);
			}
			if ($oPhoto = $this->PluginCompany_Content_AddCompanyPhoto($oPhoto)) {
				/**
				 * Если топик уже существует (редактирование), то обновляем число фоток в нём
				 */
				if (isset($oCompany)) {
					$oCompany->setPhotoCount($oCompany->getPhotoCount()+1);
					$this->PluginCompany_Company_UpdateCompanyPrefs($oCompany);
				}

				$this->Viewer_AssignAjax('file', $oPhoto->getWebPath('100crop'));
				$this->Viewer_AssignAjax('id', $oPhoto->getId());
				$this->Message_AddNotice($this->Lang_Get('plugin.company.company_photo_photo_added'), $this->Lang_Get('attention'));
			} else {
				$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
			}
		} else {
			$this->Message_AddError($this->Lang_Get('system_error'), $this->Lang_Get('error'));
		}
	}

	/**
	 * Обновление тарифа компании
	 *
	 * @return bool
	 */
	protected function AjaxUpdateTariff() {
		$this->Viewer_SetResponseAjax('json');
		/**
		 * Проверям авторизован ли пользователь
		 */
		if (!$this->User_IsAuthorization()) {
			$this->Message_AddErrorSingle($this->Lang_Get('need_authorization'),$this->Lang_Get('error'));
			return;
		}

		/**
		 * Проверяем разрешено ли менять тариф
		 */
		if (!$this->oUserCurrent->isAdministrator()) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}


		$idCompany =  getRequest('company_id');
		$idTariff = getRequest('tariff_id');
		$sPeriod = getRequest('tariff_period');
		/**
		 * Проверяем компанию
		 */
		if (!($oCompany=$this->PluginCompany_Company_GetCompanyById($idCompany))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!in_array($sPeriod,Config::Get('module.company.tariff_periods'))) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		if (!$this->PluginCompany_Pay_GetTariff($idTariff)) {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}

		$oCompany->setTariffId($idTariff);
		if ($oCompany->getDateTariffEnd())
			$oCompany->setDateTariffEnd(date("Y-m-d H:i:s", strtotime($oCompany->getDateTariffEnd())+60*60*24*$sPeriod));
		else
			$oCompany->setDateTariffEnd(date("Y-m-d H:i:s", time()+60*60*24*$sPeriod));
		// бесплатный тариф без времени
		if ($idTariff == 0){
			$oCompany->setDateTariffEnd(null);
		}

		if ($this->PluginCompany_Company_UpdateCompany($oCompany)) {
			$this->Viewer_AssignAjax('sDate',$oCompany->getDateTariffEnd());
			$this->Message_AddNoticeSingle($this->Lang_Get('plugin.company.tariff_notice_ok'),$this->Lang_Get('attention'));
		} else {
			$this->Message_AddErrorSingle($this->Lang_Get('system_error'),$this->Lang_Get('error'));
			return;
		}
	}

	/**
	 * Заполняются переменные вывода которые требуются в шапке компаний
	 *
	 * @param $oCompany
	 */
	public function CompanyHeaderVariables($oCompany){
		$iCountTender = 0;
		if ($this->oUserCurrent and $oCompany)
			$iCountTender = $this->PluginCompany_Company_GetCountTender($oCompany);

		if ($this->oUserCurrent){
			$aAllowBlogs = $this->Blog_GetBlogsAllowByUser($this->oUserCurrent);
			$this->Viewer_Assign('bCanWriteBlog',isset($aAllowBlogs[$oCompany->getBlogId()]));
		}
		$iCountCompanyTopicNew = $this->Topic_GetCountTopicsNewByCompany($oCompany);
		$iCountVacancies = 0;
		if ($this->PluginCompany_Company_isActivePlugin('job') and Config::Get('module.company.use_jobs')){
			// пока такая заглушка, в работе нет пока функции подсчета количества вакансий по компании.
			$aResult = $this->PluginJob_Job_GetVacanciesByCompanyId(1,1,$oCompany->getId());
			$iCountVacancies = $aResult['count'];
		}elseif ($oCompany->getVacancies()){
			$iCountVacancies = 1;
		}
		$this->Viewer_AddMenu('company',Plugin::GetTemplatePath('company').'menu.company.tpl');
		$this->Viewer_Assign('iCountCompanyTopicNew',$iCountCompanyTopicNew);
		$this->Viewer_Assign('iCountVacancies',$iCountVacancies);

		$this->Viewer_Assign('iCountTender',$iCountTender);

		$this->Viewer_Assign('oCompany',$oCompany);
		// блок компаний в этом городе, показываем только для бесплатных тарифов
		if ($oCompany->getTariffId()==0)
			$this->Viewer_AddBlock('right','companiesInCity',array($oCompany,'plugin'=>'company',));
		$this->Viewer_AddBlock('right','companyblog',array($oCompany,'plugin'=>'company',));

	}

	/**
	 * При завершении экшена загружаем в шаблон необходимые переменные
	 *
	 */
	public function EventShutdown() {
		if ($this->oUserCurrent){
			// Проверяем может ли пользователь добавить компанию, нужно для меню
			$bCanAddCompany=$this->ACL_CanCreateCompany($this->oUserCurrent);
			$this->Viewer_Assign('bCanAddCompany',$bCanAddCompany);
			// по сути нужно переделать в функцию, чтобы получать компании которые нельзя показывать, т.е. не активированные.
			$this->Viewer_Assign('iCountFavCompanies',$this->PluginCompany_Company_GetCountFavCompaniesByUser($this->oUserCurrent->getId()));
			//при завершении обновляем значение переменной компаний пользователя
			$this->aUserCompany = $this->PluginCompany_Company_GetCompaniesByUser($this->oUserCurrent->getId(),true);
			$this->Viewer_Assign('aUserCompany',$this->aUserCompany);
			// если только одна компания то выводим прямую ссылку на нее и количество заявок
			if (count($this->aUserCompany) == 1){
				$oUserCompany = reset($this->aUserCompany);
				$this->Viewer_Assign('oUserCompany',$oUserCompany);
				//$this->Viewer_Assign('iCountTender',$this->PluginCompany_Company_GetCountTender($oUserCompany));
			}
			if (Config::Get('module.company.use_activate') and $this->oUserCurrent->isAdministrator())
				$this->Viewer_Assign('iCountModeration',$this->PluginCompany_Company_GetCountCompaniesByFilter(array('active' => 0)));
		}

		/**
		 * Загружаем переменные в шаблон
		 */
		$this->Viewer_Assign('sCompanyTemplatePath',$this->getTemplatePathPlugin()); //`$aTemplatePathPlugin['company']`
		$this->Viewer_Assign('sMenuHeadItemSelect',$this->sMenuHeadItemSelect);
		$this->Viewer_Assign('sMenuItemSelect',$this->sMenuItemSelect);
		$this->Viewer_Assign('sMenuSubItemSelect',$this->sMenuSubItemSelect);

		$this->Viewer_Assign('iCountNewCompanies',$this->PluginCompany_Company_GetCountCompaniesByFilter(array('new_time' => Config::Get('module.company.new_time'))));
		$this->Viewer_Assign('iCountCompanies',$this->PluginCompany_Company_GetCountCompaniesByFilter());
	}
}
?>
