<?php
/**
 *	Module "Company"
 *	Author: Grebenkin Anton
 *	Contact e-mail: 4freework@gmail.com
 */
class PluginCompany_ModuleCompany extends Module {
	protected $oMapper;
	protected $oUserCurrent=null;

	/**
	 * Инициализация
	 */
	public function Init() {
		$this->oMapper=Engine::GetMapper(__CLASS__);
		$this->oUserCurrent = $this->User_GetUserCurrent();
		$this->oMapper->SetUserCurrent($this->oUserCurrent);
	}

	/**
	 * Получает дополнительные данные(объекты) для компаний по их ID
	 *
	 * @param $aCompanyId ид компании
	 * @param null $aAllowData
	 * @return array массив компаний
	 */
	public function GetCompaniesAdditionalData($aCompanyId,$aAllowData=null) {
		if (is_null($aAllowData)) {
			$aAllowData=array('owner'=>array(),'blog'=>array('owner'=>array(),'relation_user'),'vote','favourite','geo_target','topic_last'=>array('blog'=>array(),'user'=>array()));
		}
		func_array_simpleflip($aAllowData);
		if (!is_array($aCompanyId)) {
			$aCompanyId=array($aCompanyId);
		}
		$aCompanies=$this->GetCompaniesByArrayId($aCompanyId);
		/**
		 * Формируем ID дополнительных данных, которые нужно получить
		 */
		$aUserId=array();
		$aBlogId=array();
		$aTopicId=array();
		$aPhotoMainId=array();
		foreach ($aCompanies as $oCompany) {
			if (isset($aAllowData['owner'])) {
				$aUserId[]=$oCompany->getOwnerId();
			}
			if (isset($aAllowData['blog'])) {
				$aBlogId[]=$oCompany->getBlogId();
			}
			if (isset($aAllowData['topic_last'])) {
				$aTopicId[]=$oCompany->getTopicIdLast();
			}
			if ($oCompany->getMainPhotoId())	{
				$aPhotoMainId[]=$oCompany->getMainPhotoId();
			}
		}
		$aGeoTargets=array();
		if (isset($aAllowData['geo_target'])) {
			$aGeoTargets=$this->Geo_GetCompanyTargetsByArray($aCompanyId);
			//$aGeoTargets=$this->Geo_GetTargetsByTargetArray('company',$aCompanyId);
		}
		/**
		 * Получаем дополнительные данные
		 */
		$aUsers=isset($aAllowData['owner']) && is_array($aAllowData['owner']) ? $this->User_GetUsersAdditionalData($aUserId,$aAllowData['owner']) : $this->User_GetUsersAdditionalData($aUserId);

		$aBlogs = array();
		if (isset($aAllowData['blog'])) {
			$aBlogs=isset($aAllowData['blog']) && is_array($aAllowData['blog']) ? $this->Blog_GetBlogsAdditionalData($aBlogId,$aAllowData['blog']) : $this->Blog_GetBlogsAdditionalData($aBlogId);
		}
		$aTopics = array();
		if (isset($aAllowData['topic_last'])) {
			$aTopics=isset($aAllowData['topic_last']) && is_array($aAllowData['topic_last']) ? $this->Topic_GetTopicsAdditionalData($aTopicId,$aAllowData['topic_last']) : $this->Topic_GetTopicsAdditionalData($aTopicId,array('blog'=>array(),'user'=>array()));
		}

		$aFavouriteComapanies=array();
		if (isset($aAllowData['favourite']) and $this->oUserCurrent) {
			$aFavouriteComapanies=$this->Favourite_GetFavouritesByArray($aCompanyId,'company',$this->oUserCurrent->getId());
		}

		$aCompanyVote=array();
		if (isset($aAllowData['vote']) and $this->oUserCurrent) {
			$aCompanyVote=$this->Vote_GetVoteByArray($aCompanyId,'company',$this->oUserCurrent->getId());
		}
		$aMainPhotos=$this->PluginCompany_Content_GetCompanyPhotosByArrayId($aPhotoMainId);
		/**
		 * Добавляем данные к результату - списку топиков
		 */
		foreach ($aCompanies as $oCompany) {
			if (isset($aUsers[$oCompany->getOwnerId()])) {
				$oCompany->setOwner($aUsers[$oCompany->getOwnerId()]);
			} else {
				$oCompany->setOwner(null);
			}
			if (isset($aBlogs[$oCompany->getBlogId()])) {
				$oCompany->setBlog($aBlogs[$oCompany->getBlogId()]);
				$oCompany->setUserIsJoin($oCompany->getBlog()->getUserIsJoin());
				$oCompany->setUserIsAdministrator($oCompany->getBlog()->getUserIsAdministrator());
				$oCompany->setUserIsModerator($oCompany->getBlog()->getUserIsModerator());
			} else {
				$oCompany->setBlog(null);
			}

			if (isset($aTopics[$oCompany->getTopicIdLast()])) {
				$oCompany->setTopicLast($aTopics[$oCompany->getTopicIdLast()]);
			} else {
				$oCompany->setTopicLast(null);
			}

			if (isset($aFavouriteComapanies[$oCompany->getId()])) {
				$oCompany->setIsFavourite(true);
			} else {
				$oCompany->setIsFavourite(false);
			}
			if (isset($aCompanyVote[$oCompany->getId()])) {
				$oCompany->setVote($aCompanyVote[$oCompany->getId()]);
			} else {
				$oCompany->setVote(null);
			}

			if (isset($aGeoTargets[$oCompany->getId()])) {
				$aTargets=$aGeoTargets[$oCompany->getId()];
				$oCompany->setGeoTarget(isset($aTargets[0]) ? $aTargets[0] : null);
			} else {
				$oCompany->setGeoTarget(null);
			}

			if (isset($aMainPhotos[$oCompany->getMainPhotoId()])) {
				$oCompany->setMainPhoto($aMainPhotos[$oCompany->getMainPhotoId()]);
			} else {
				$oCompany->setMainPhoto(null);
			}

		}
		return $aCompanies;
	}

	/**
	 * Получает массив компании по массиву id компаний
	 *
	 * @param $aCompanyId
	 * @return array
	 */
	public function GetCompaniesByArrayId($aCompanyId) {
		if (!$aCompanyId) {
			return array();
		}
		if (!is_array($aCompanyId)) {
			$aCompanyId=array($aCompanyId);
		}
		$aCompanyId=array_unique($aCompanyId);
		$aCompanies=array();
		$aCompanyIdNotNeedQuery=array();
		/**
		 * Делаем мульти-запрос к кешу
		 */
		$aCacheKeys = func_build_cache_keys($aCompanyId,'company_');
		if (false !== ($data = $this->Cache_Get($aCacheKeys))) {
			/**
			 * проверяем что досталось из кеша
			 */
			foreach ($aCacheKeys as $sValue => $sKey ) {
				if (array_key_exists($sKey,$data)) {
					if ($data[$sKey]) {
						$aCompanies[$data[$sKey]->getId()]=$data[$sKey];
					} else {
						$aCompanyIdNotNeedQuery[]=$sValue;
					}
				}
			}
		}
		/**
		 * Смотрим каких юзеров не было в кеше и делаем запрос в БД
		 */
		$aCompanyIdNeedQuery=array_diff($aCompanyId,array_keys($aCompanies));
		$aCompanyIdNeedQuery=array_diff($aCompanyIdNeedQuery,$aCompanyIdNotNeedQuery);
		$aCompanyIdNeedStore=$aCompanyIdNeedQuery;
		if ($data = $this->oMapper->GetCompaniesByArrayId($aCompanyIdNeedQuery)) {
			foreach ($data as $oCompany) {
				/**
				 * Добавляем к результату и сохраняем в кеш
				 */
				$aCompanies[$oCompany->getId()]=$oCompany;
				$this->Cache_Set($oCompany, "company_{$oCompany->getId()}", array(), 60*60*24*4);
				$aCompanyIdNeedStore=array_diff($aCompanyIdNeedStore,array($oCompany->getId()));
			}
		}
		/**
		 * Сохраняем в кеш запросы не вернувшие результата
		 */
		foreach ($aCompanyIdNeedStore as $sId) {
			$this->Cache_Set(null, "company_{$sId}", array(), 60*60*24*4);
		}
		/**
		 * Сортируем результат согласно входящему массиву
		 */
		return func_array_sort_by_keys($aCompanies,$aCompanyId);
	}

	/**
	 * Получает компании по фильтру
	 *
	 * @param $aFilter фильтр
	 * @param $aOrder сортировка
	 * @param $iCurrPage текущая страница
	 * @param $iPerPage количество записей на странице
	 * @param null $aAllowData доступные данные
	 * @return array
	 */
	public function GetCompaniesByFilter($aFilter,$aOrder,$iCurrPage=1,$iPerPage=100,$aAllowData=null) {
		// если используется активация, то показываем только активированные
		if (Config::Get('module.company.use_activate') and !isset($aFilter['active']) and !isset($aFilter['all']))
			$aFilter['active'] = 1;
		$sKey="companies_filter_".serialize($aFilter).serialize($aOrder)."_{$iCurrPage}_{$iPerPage}";
		if (false === ($data = $this->Cache_Get($sKey))) {
			$data = array('collection'=>$this->oMapper->GetCompaniesByFilter($aFilter,$aOrder,$iCount,$iCurrPage,$iPerPage),'count'=>$iCount);
			$this->Cache_Set($data, $sKey, array("company_update","company_new"), 60*60*24*2);
		}
		$data['collection']=$this->GetCompaniesAdditionalData($data['collection'],$aAllowData);
		return $data;
	}

	/**
	 * Получает комании в которых работает пользователь
	 *
	 * @param $sUserId ИД пользователя
	 * @param bool $bWithOwner включать создателя компании, или только работники
	 * @return mixed
	 */
	public function GetCompaniesByUser($sUserId,$bWithOwner=false) {
		$Ids = $this->Blog_GetBlogUsersByUserId($sUserId,array(ModuleBlog::BLOG_USER_ROLE_USER,ModuleBlog::BLOG_USER_ROLE_MODERATOR,ModuleBlog::BLOG_USER_ROLE_ADMINISTRATOR), true);
		if ($bWithOwner){ // Добавляем еще хозяев компаний
			$Ids = array_merge($this->Blog_GetBlogsByOwnerId($sUserId,true), $Ids);
		}
		$aCompanies = $this->GetCompaniesByFilter(array('blog_id' => $Ids),array(),1,1000);
		return $aCompanies['collection'];
	}

	/*
	 * Получает список компаний по тегу
	 */
	public function GetCompaniesByTag($sTag,$iPage,$iPerPage) {
		if (false === ($data = $this->Cache_Get("company_tag_{$sTag}_{$iPage}_{$iPerPage}"))) {
			$data = array('collection'=>$this->oMapper->GetCompaniesByTag($sTag,$iCount,$iPage,$iPerPage),'count'=>$iCount);
			$this->Cache_Set($data, "company_tag_{$sTag}_{$iPage}_{$iPerPage}", array('company_update','company_new'), 60*60*24);
		}
		$data['collection'] = $this->GetCompaniesByArrayId($data['collection']);
		return $data;
	}


	/**
	 * Получить компанию по идентификатору
	 *
	 * @param $sCompanyId
	 * @return null
	 */
	public function GetCompanyById($sCompanyId) {
		$aCompanies = $this->GetCompaniesAdditionalData($sCompanyId,array('owner'=>array(),'blog'=>array('owner'=>array(),'relation_user'),'vote','favourite','geo_target'));
		if (isset($aCompanies[$sCompanyId])) {
			return $aCompanies[$sCompanyId];
		}
		return null;
	}

	/**
	 * Получить компанию по id блога
	 *
	 * @param $sBlogId
	 * @return PluginCompany_ModuleCompany_EntityCompany
	 */
	public function GetCompanyByBlogId($sBlogId) {
		if (false === ($id = $this->Cache_Get("company_blog_{$sBlogId}"))) {
			if ($id = $this->oMapper->GetCompanyByBlogId($sBlogId)) {
				$this->Cache_Set($id, "company_blog_{$sBlogId}", array("company_update_{$id}",'company_new'), 60*60*24);
			} else {
				$this->Cache_Set(null, "company_blog_{$sBlogId}", array('company_update','company_new'), 60*60*24);
			}
		}
		return $this->GetCompanyById($id);
	}

	/**
	 * Получить компанию по алиасу
	 *
	 * @param $sCompanyUrl
	 * @return PluginCompany_ModuleCompany_EntityCompany
	 */
	public function GetCompanyByUrl($sCompanyUrl) {
		if (false === ($id = $this->Cache_Get("company_url_{$sCompanyUrl}"))) {
			if ($id = $this->oMapper->GetCompanyByUrl($sCompanyUrl)) {
				$this->Cache_Set($id, "company_url_{$sCompanyUrl}", array("company_update_{$id}",'company_new'), 60*60*24);
			} else {
				$this->Cache_Set(null, "company_url_{$sCompanyUrl}", array('company_update','company_new'), 60*60*24);
			}
		}
		return $this->GetCompanyById($id);
	}

	public function GetCompanyExist($sCompanyUrl) {
		if ($this->GetCompanyByUrl($sCompanyUrl))
			return true;
		return false;
	}

	/**
	 * Получить компанию по названию
	 *
	 * @param $sName
	 * @return PluginCompany_ModuleCompany_EntityCompany
	 */
	public function GetCompanyByName($sName) {
		if (false === ($id = $this->Cache_Get("company_name_{$sName}"))) {
			if ($id = $this->oMapper->GetCompanyByName($sName)) {
				$this->Cache_Set($id, "company_name_{$sName}", array("company_update_{$id}",'company_new'), 60*60*24);
			} else {
				$this->Cache_Set(null, "company_name_{$sName}", array('company_update','company_new'), 60*60*24);
			}
		}
		return $this->GetCompanyById($id);
	}

	/*
	 * Получает список тегов компаний по первым буквам тега
	 */
	public function GetCompanyTagsByLike($sTag,$iLimit) {
		if (false === ($data = $this->Cache_Get("company_tag_like_{$sTag}_{$iLimit}"))) {
			$data = $this->oMapper->GetCompanyTagsByLike($sTag,$iLimit);
			$this->Cache_Set($data, "company_tag_like_{$sTag}_{$iLimit}", array("company_update","company_new"), 60*60*24);
		}
		return $data;
	}

	/*
	 * Получает список тегов компаний
	 */
	public function GetCompanyTags($iLimit) {
		if (false === ($data = $this->Cache_Get("companytag_{$iLimit}"))) {
			$data = $this->oMapper->GetCompanyTags($iLimit);
			$this->Cache_Set($data, "companytag_{$iLimit}", array('company_update','company_new'), 60*60*24);
		}
		return $data;
	}

	/**
	 * Получает теги компании по id
	 *
	 * @param $iCompanyId
	 * @return mixed
	 */
	public function GetCompanyTagsByCompanyId($iCompanyId) {
		if (false === ($data = $this->Cache_Get("company_category_{$iCompanyId}"))) {
			$data = $this->oMapper->GetCompanyTagsByCompanyId($iCompanyId);
			$this->Cache_Set($data, "company_category_{$iCompanyId}", array('company_update','company_new'), 60*60*24);
		}
		return $data;
	}

	/**
	 * Количество компаний по фильтру
	 *
	 * @param array() $aFilter
	 * @return int
	 */
	public function GetCountCompaniesByFilter($aFilter = array()) {
		if (Config::Get('module.company.use_activate') and !isset($aFilter['active']))
			$aFilter['active'] = 1;
		$s=serialize($aFilter);
		if (false === ($data = $this->Cache_Get("company_count_{$s}"))) {
			$data = $this->oMapper->GetCountCompaniesByFilter($aFilter);
			$this->Cache_Set($data, "company_count_{$s}", array('company_update','company_new'), 60*60*24);
		}
		return 	$data;
	}

	/**
	 * Получает количество избранных пользователем компаний
	 *
	 * @param $sUserId
	 * @return int
	 */
	public function GetCountFavCompaniesByUser($sUserId) {
		$aFavCompanies = $this->GetFavouriteCompaniesByUserId($sUserId,1,100);
		return 	$aFavCompanies['count'];
	}

	/**
	 * Количество заявок которые поступили на вступление в компанию
	 *
	 * @param $oCompany
	 * @return int
	 */
	public function GetCountTender($oCompany) {
		if (false === ($data = $this->Cache_Get("company_{$oCompany->getId()}_tender_count"))) {
			$aBlogUsers = $this->Blog_GetBlogUsersByBlogId($oCompany->getBlogId(), array(ModuleBlog::BLOG_USER_ROLE_GUEST));
			$data = $aBlogUsers['count'];
			$this->Cache_Set($data, "company_{$oCompany->getId()}_tender_count}", array("blog_relation_change_blog_{$oCompany->getBlogId()}"), 60*60*24);
		}
		return $data;
	}


	/**
	 * Добавляет компанию
	 *
	 * @param PluginCompany_ModuleCompany_EntityCompany $oCompany
	 * @return bool|PluginCompany_ModuleCompany_EntityCompany
	 */
	public function AddCompany(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		// Создаем блог компании
		if ($oBlog = $this->CreateCompanyBlog($oCompany)){
			$oCompany->setBlogId($oBlog->getId());

			// Создаем саму компанию
			if ($sId=$this->oMapper->AddCompany($oCompany)) {
				$oCompany->setId($sId);
				// разбираем и добавляем теги.
				$aTags=explode(',',$oCompany->getTags());
				foreach ($aTags as $sTag) {
					$oTag=Engine::GetEntity('PluginCompany_Company_CompanyTag');//new ModuleCompany_EntityCompanyTag();
					$oTag->setCompanyId($oCompany->getId());
					$oTag->setUserId($oCompany->getOwnerId());
					$oTag->setText(trim($sTag));
					$this->oMapper->AddCompanyTag($oTag);
				}

				//чистим зависимые кеши
				$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_new'));
				return $oCompany;
			}
		}
		return false;
	}

	/**
	 * Удаление компании
	 * Если тип таблиц в БД InnoDB, то удалятся всё связи по компании.
	 *
	 * @param $sCompanyId
	 * @return mixed
	 */
	public function DeleteCompany($sCompanyId) {
		$oCompany = $this->GetCompanyById($sCompanyId);
		$this->Blog_DeleteBlog($oCompany->getBlogId());
		$this->Comment_DeleteCommentByTargetId($sCompanyId,'company');
		$this->Comment_DeleteCommentOnlineByTargetId($sCompanyId,'company');
		$this->Favourite_DeleteFavouriteByTargetId($sCompanyId,'company');
		$this->Geo_DeleteTargetsByTarget('company',$sCompanyId);
		$this->DeleteCompanyTagsByCompanyId($oCompany->getId());

		//чистим зависимые кеши
		$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$oCompany->getId()}"));
		$this->Cache_Delete("company_{$sCompanyId}");
		return $this->oMapper->DeleteCompany($sCompanyId);
	}

	/**
	 * Удаление тегов компании
	 *
	 * @param $sCompanyId
	 * @return mixed
	 */
	public function DeleteCompanyTagsByCompanyId($sCompanyId) {
		return $this->oMapper->DeleteCompanyTagsByCompanyId($sCompanyId);
	}

	/**
	 * Обновляет компанию
	 *
	 * @param PluginCompany_ModuleCompany_EntityCompany $oCompany
	 * @return bool
	 */
	public function UpdateCompany(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		if ($this->oMapper->UpdateCompany($oCompany)) {
			$this->UpdateCompanyBlog($oCompany);
			//чистим зависимые кеши
			$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$oCompany->getId()}"));
			$this->Cache_Delete("company_{$oCompany->getId()}");
			return true;
		}
		return false;
	}

	/**
	 * Обновляет теги компании
	 * @param PluginCompany_ModuleCompany_EntityCompany $oCompany
	 * @return bool
	 */
	public function UpdateCompanyTags(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		// разбираем и добавляем теги.
		$aTags = explode(',', $oCompany->getTags());
		$this->DeleteCompanyTagsByCompanyId($oCompany->getId());
		foreach ($aTags as $sTag) {
			$oTag = Engine::GetEntity('PluginCompany_Company_CompanyTag'); //ModuleCompany_EntityCompanyTag();
			$oTag->setCompanyId($oCompany->getId());
			$oTag->setUserId($oCompany->getOwnerId());
			$oTag->setText($sTag);
			$this->oMapper->AddCompanyTag($oTag);
		}
		return true;
	}

	/**
	 * Обновляет настройки компании
	 *
	 * @param PluginCompany_ModuleCompany_EntityCompany $oCompany
	 * @return bool
	 */
	public function UpdateCompanyPrefs(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		if ($this->oMapper->UpdateCompanyPrefs($oCompany)) {
			//чистим зависимые кеши
			//$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$oCompany->getId()}"));
			$this->Cache_Delete("company_{$oCompany->getId()}");
			return true;
		}
		return false;
	}

	/*
    * Обновляет описание и заголовок корпоративного блога
    */
	public function UpdateCompanyBlog(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$oBlog = $this->Blog_GetBlogById($oCompany->getBlogId());
		$oBlog->setTitle($this->Lang_Get('plugin.company.company_blog_prefix').' '.$oCompany->getName());
		$oBlog->setDescription($oCompany->getDescription());
		$oBlog->setUrl('company_company_'.$oCompany->GetUrl()); // Для того чтобы не терялся префикс при апдейте
		$oBlog->setAvatar($oCompany->getLogoPath(100));
		return $this->Blog_UpdateBlog($oBlog);
	}
	/*
	 * Создаёт корпоративный блог
	 */
	public function CreateCompanyBlog(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$oBlog = Engine::GetEntity('Blog');//BlogEntity_Blog();
		$oBlog->setOwnerId($oCompany->getOwnerId());
		$oBlog->setTitle($this->Lang_Get('plugin.company.company_blog_prefix').' '.$oCompany->getName());
		$oBlog->setType('company');
		$oBlog->setDescription($oCompany->getDescription());
		$oBlog->setDateAdd(date("Y-m-d H:i:s"));
		$oBlog->setLimitRatingTopic(-100);
		$oBlog->setUrl('company_company_'.$oCompany->GetUrl());	// company_ вырезается в getUrl() поэтому при создании пишем 2 раза..
		$oBlog->setAvatar(null);
		return $this->Blog_AddBlog($oBlog);
	}


	/*
	 * Увеличивает число отзывов о компании
	 */
	public function increaseCompanyCountFeedbacks($sCompanyId) {
		$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$sCompanyId}"));
		$this->Cache_Delete("company_{$sCompanyId}");
		return $this->oMapper->increaseCompanyCountFeedbacks($sCompanyId);
	}

	/**
	 * Увеличивает число подписчиков на блог компании
	 *
	 * @param $sCompanyId
	 * @return mixed
	 */
	public function increaseCompanyCountSubscribe($sCompanyId) {
		$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$sCompanyId}"));
		$this->Cache_Delete("company_{$sCompanyId}");
		return $this->oMapper->increaseCompanyCountSubscribe($sCompanyId);
	}

	/**
	 * Уменьшает число подписчиков на блог компании
	 *
	 * @param $sCompanyId
	 * @return mixed
	 */
	public function decreaseCompanyCountSubscribe($sCompanyId) {
		$this->Cache_Clean(Zend_Cache::CLEANING_MODE_MATCHING_TAG,array('company_update',"company_update_{$sCompanyId}"));
		$this->Cache_Delete("company_{$sCompanyId}");
		return $this->oMapper->decreaseCompanyCountSubscribe($sCompanyId);
	}

	/*
	 * Получает дату прочтения отзывов компании юзером
	 */
	public function GetFeedbackRead($sCompanyId,$sUserId) {
		return $this->oMapper->GetFeedbackRead($sCompanyId,$sUserId);
	}

	/*
	 * Обновляем/устанавливаем дату прочтения отзыва, если читаем его первый раз то добавляем
	 */
	public function SetFeedbackRead(PluginCompany_ModuleCompany_EntityCompanyFeedbackRead $oFeedbackRead) {
		if ($this->GetFeedbackRead($oFeedbackRead->getCompanyId(),$oFeedbackRead->getUserId())) {
			$this->oMapper->UpdateFeedbackRead($oFeedbackRead);
		} else {
			$this->oMapper->AddFeedbackRead($oFeedbackRead);
		}
		return true;
	}


	/**
	 * Расчет рейтинга и силы при голосовании за компанию
	 *
	 * @param ModuleUser_EntityUser $oUser
	 * @param PluginCompany_ModuleCompany_EntityCompany $oCompany
	 * @param int $iValue
	 * @return int
	 */
	public function VoteCompany(ModuleUser_EntityUser $oUser, PluginCompany_ModuleCompany_EntityCompany $oCompany, $iValue) {
		/**
		 * Устанавливаем рейтинг блога, используя логарифмическое распределение
		 */
		$skill=$oUser->getSkill();
		$iMinSize=1.13;
		$iMaxSize=15;
		$iSizeRange=$iMaxSize-$iMinSize;
		$iMinCount=log(0+1);
		$iMaxCount=log(500+1);
		$iCountRange=$iMaxCount-$iMinCount;
		if ($iCountRange==0) {
			$iCountRange=1;
		}
		if ($skill>50 and $skill<200) {
			$skill_new=$skill/20;
		} elseif ($skill>=200) {
			$skill_new=$skill/10;
		} else {
			$skill_new=$skill/50;
		}
		$iDelta=$iMinSize+(log($skill_new+1)-$iMinCount)*($iSizeRange/$iCountRange);
		/**
		 * Сохраняем рейтинг
		 */
		$oCompany->setRating($oCompany->getRating()+$iValue*$iDelta);
		return $iDelta;
	}

	/**
	 * Изменяет владельца компании
	 *
	 * @param ModuleBlog_EntityBlog $oBlog
	 * @param ModuleUser_EntityUser $oUser
	 * @return bool
	 */
	public function ReplaceCompanyOwner(ModuleBlog_EntityBlog $oBlog, ModuleUser_EntityUser $oUser) {
		$oBlog->setOwnerId($oUser->getId());
		$this->oMapper->UpdateCompanyBlogOwner($oBlog);
		$this->oMapper->UpdateCompanyOwner($oBlog);
		// Если пользователь был в уже в компании.
		$oBlogUser=$this->Blog_GetBlogUserByBlogIdAndUserId($oBlog->getId(),$oUser->getId());
		if ($oBlogUser){
			$this->Blog_DeleteRelationBlogUser($oBlogUser);
		}
		$oBlog->setUrl('company_company_'.$oBlog->getUrl());
		$this->Blog_UpdateBlog($oBlog);
		return true;
	}

	/**
	 * Проверяет является ли пользователь сотрудником компании
	 *
	 * @param $sUserId
	 * @param $oCompany
	 * @return bool
	 */
	public function GetUserIsEmployee($sUserId,$oCompany) {
		$aUserCompanies = $this->GetCompaniesByUser($sUserId, true);
		if (isset($aUserCompanies[$oCompany->getId()])) {
			return true;
		}
		return false;
	}

	/**
	 * Получает неактивные блоги компаний
	 *
	 * @return array
	 */
	public function GetInaccessibleCompanyBlogs() {
		if ($this->oUserCurrent && $this->oUserCurrent->isAdministrator()) {
			return array();
		}
		return $aCloseBlogs = $this->oMapper->GetCompanyInactiveBlogs();
	}

	/**
	 * Получает активные блоги компаний
	 *
	 * @return array
	 */
	public function GetCompanyActiveBlogs() {
		if (false === ($data = $this->Cache_Get("company_active_blogs"))) {
			$data = $this->oMapper->GetCompanyActiveBlogs();
			$this->Cache_Set($data, "company_active_blogs", array('company_update','company_new'), 60*60*24);
		}
		return $data;
	}

	/**
	 * Проверяет активирова ли плагин
	 *
	 * @param $sPluginName
	 * @return bool
	 */
	public function isActivePlugin($sPluginName) {
		$aPluginList = array_keys($this->oEngine->GetPlugins());
		if (in_array(strtolower($sPluginName),$aPluginList)){
			return true;
		}
		return false;
	}

	/**
	 * Получает список пользователей из избранного
	 *
	 * @param  string $sTargetId
	 * @param  string $sTargetType
	 * @param  int $iCurrPage
	 * @param  int $iPerPage
	 * @return array
	 */
	public function GetFavouriteUsersByTargerId($sTargetId,$sTargetType,$iCurrPage,$iPerPage) {
		if (false === ($data = $this->Cache_Get("{$sTargetType}_favourite_target_{$sTargetId}_{$iCurrPage}_{$iPerPage}"))) {
			$data = $this->oMapper->GetFavouriteUsersByTargerId($sTargetId,$sTargetType,$iCurrPage,$iPerPage);
			$this->Cache_Set($data, "{$sTargetType}_favourite_target_{$sTargetId}_{$iCurrPage}_{$iPerPage}", array("favourite_{$sTargetType}_change"), 60*60*24);
		}
		return $data;
	}

	/**
	 * Получает избранные компании пользователя
	 *
	 * @param $iUserId
	 * @param $iCurrPage
	 * @param $iPerPage
	 * @return array
	 */
	public function GetFavouriteCompaniesByUserId($iUserId,$iCurrPage,$iPerPage) {
		$data = $this->Favourite_GetFavouritesByUserId($iUserId,'company',$iCurrPage,$iPerPage);
		return $this->GetCompaniesByFilter(array('company_id' => $data['collection']),array(),$iCurrPage,$iPerPage);
	}

	/**
	 * Отсылает уведомления о новом топике подписчикам
	 *
	 * @param $oTopic
	 */
	public function SendSubscribeNewTopic($oTopic){
		$oCompany = $oCompany=$this->GetCompanyByBlogId($oTopic->getBlogId());
		// Отсылаем только если компания активна
		if ($oCompany) {
			// получаем дополнительные данные топика
			$oTopic=$this->Topic_GetTopicById($oTopic->getId());
			$aExcludeMail=array($this->oUserCurrent->getMail());
			$this->Subscribe_Send('company_new_topic', $oCompany->getId(), 'notify.company_new_topic.tpl', $this->Lang_Get('plugin.company.notify_subject_topic_new').' '.$oCompany->getName(), array(
				'oTopic' => $oTopic,
				'oCompany' => $oCompany,
			), $aExcludeMail,'PluginCompany');
		}
	}

	public function GetJSON($url){
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		$data=curl_exec($ch);
		curl_close($ch);
		return json_decode($data,true);
	}

	public function CheckAndSaveTwitterAccount(PluginCompany_ModuleCompany_EntityCompany $oCompany, $screenName) {
		$screenName = strip_tags($screenName);
		if ($this->PluginCompany_Oauth_CheckTwitterName($screenName)) {
			$oCompany->setTwitterScreenName($screenName);
			$this->UpdateCompanyPrefs($oCompany);
			return true;
		}
		return false;
	}


	public function CheckAndSaveFBAccount(PluginCompany_ModuleCompany_EntityCompany $oCompany,$fbUrl) {
		$data = $this->GetJSON('http://graph.facebook.com/'.strip_tags($fbUrl));
		if (isset($data['link'])){
			$oCompany->setFbUrl($data['link']);
			$this->UpdateCompanyPrefs($oCompany);
			return true;
		}
		return false;
	}

	public function CheckAndSaveVkAccount(PluginCompany_ModuleCompany_EntityCompany $oCompany,$vkUrl) {
		$data = $this->GetJSON('http://api.vk.com/method/groups.getById?gid='.strip_tags($vkUrl));
		if (isset($data['response']['0']['screen_name'])){
			$response = $data['response']['0'];
			$oCompany->setVkUrl('http://vk.com/'.$response['screen_name']);
			$oCompany->setVkId($response['gid']);
			$this->UpdateCompanyPrefs($oCompany);
			return true;
		}
		return false;
	}

}
?>