<?php
/**
 *	Module "Company"
 *	Author: Grebenkin Anton
 *	Contact e-mail: 4freework@gmail.com
 */

class PluginCompany_ModuleCompany_MapperCompany extends Mapper {
	protected $oUserCurrent=null;

	public function SetUserCurrent($oUserCurrent) {
		$this->oUserCurrent=$oUserCurrent;
	}

	/* КОМПАНИИ */

	public function AddCompany(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$sql = "INSERT INTO ".Config::Get('db.table.company')."
			(user_owner_id,
			company_url,
			company_name,
			company_description,
			company_tags,
			company_country,
			company_city,
			company_date_add,
			company_vacancies,
			company_prefs,
			company_type,
			blog_id
			)
			VALUES(?d,  ?,	?,	?,	?,	?, ?, ?, ?, ?, ?, ?d)
		";
		if ($iId=$this->oDb->query($sql,$oCompany->getOwnerId(),$oCompany->getUrl(),$oCompany->getName(),$oCompany->getDescription(),$oCompany->getTags(),$oCompany->getCountry(),$oCompany->getCity(),$oCompany->getDateAdd(),'','',$oCompany->getType(),$oCompany->getBlogId())) {
			return $iId;
		}
		return false;
	}

	public function UpdateCompany(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				company_name= ?,
				company_name_legal= ?,
				company_description= ?,
				company_site= ?,
				company_email= ?,
				company_phone= ?,
				company_fax= ?,
				company_contact_name= ?,
				company_date_basis= ?,
				company_date_edit= ?,
				company_tags= ?,
				company_country= ?,
				company_city= ?,
				company_address= ?,
				company_count_workers= ?,
				company_rating= ?f,
				company_count_vote = ?d,
				company_logo=	?d,
				company_logo_type=	?,
				company_vacancies=	?,
				company_active=	?d,
				company_latitude = ?,
				company_longitude = ?,
				company_count_favourite= ?d,
				company_file_name = ?,
				company_skype= ?,
				company_icq = ?,
				company_contact_info = ?,
				company_about = ?,
				company_about_source = ?,
				topic_id_last = ?d,
				company_prefs = ?,
				company_tariff_id = ?d,
				company_date_tariff_end = ?
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$oCompany->getName(),$oCompany->getLegalName(),$oCompany->getDescription(),
			$oCompany->getSite(),$oCompany->getEmail(),$oCompany->getPhone(),$oCompany->getFax(),$oCompany->getContactName(),$oCompany->getDateBasis(),$oCompany->getDateEdit(),
			$oCompany->getTags(),$oCompany->getCountry(),$oCompany->getCity(),$oCompany->getAddress(),$oCompany->getCountWorkers(),$oCompany->getRating(),
			$oCompany->getCountVote(),$oCompany->getLogo(),$oCompany->getLogoType(),$oCompany->getVacancies(),$oCompany->getActive(),
			$oCompany->getLatitude(),$oCompany->getLongitude(),$oCompany->getCountFavourite(),$oCompany->getFileName(),$oCompany->getSkype(),$oCompany->getIcq(),
			$oCompany->getContactInfo(),$oCompany->getAbout(),$oCompany->getAboutSource(),$oCompany->getTopicIdLast(),$oCompany->getPrefs(),$oCompany->getTariffId(),$oCompany->getDateTariffEnd(),
			$oCompany->getId())) {
			return true;
		}
		return false;
	}

	public function UpdateCompanyPrefs(PluginCompany_ModuleCompany_EntityCompany $oCompany) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				company_prefs = ?
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$oCompany->getPrefs(),
			$oCompany->getId())) {
			return true;
		}
		return false;
	}


	public function GetCompanyByName($sName) {
		$sql = "SELECT company_id FROM ".Config::Get('db.table.company')." WHERE company_name = ? ";
		if ($aRow=$this->oDb->selectRow($sql,$sName)) {
			return $aRow['company_id'];
		}
		return null;
	}

	public function GetCompanyByBlogId($sId) {
		$sql = "SELECT company_id FROM ".Config::Get('db.table.company')."  WHERE blog_id = ?d ";
		if ($aRow=$this->oDb->selectRow($sql,$sId)) {
			return $aRow['company_id'];
		}
		return null;
	}

	/*
	 * Возвращает id компании по заданному алиасу
	 */
	public function GetCompanyByUrl($sUrl, $bOnlyActive = true) {
		$sql = "SELECT
				company_id
			FROM
				".Config::Get('db.table.company')."
			WHERE
				LOWER(company_url) = ?
				";
		if ($aRow=$this->oDb->selectRow($sql,$sUrl)) {
			return $aRow['company_id'];
		}
		return null;
	}

	public function GetCompanyTags($iLimit) {
		$sql = "SELECT
			tt.company_tag_text,
			count(tt.company_tag_text)	as count
			FROM
				".Config::Get('db.table.company_tag')." as tt,
				".Config::Get('db.table.company')." as t
			WHERE
				t.company_id=tt.company_id
			GROUP BY
				tt.company_tag_text
			ORDER BY
				count desc
			LIMIT 0, ?d
				";
		$aReturn=array();
		$aReturnSort=array();
		if ($aRows=$this->oDb->select($sql,$iLimit)) {
			foreach ($aRows as $aRow) {
				$aReturn[$aRow['company_tag_text']]=$aRow;
			}
			ksort($aReturn);
			foreach ($aReturn as $aRow) {
				$aReturnSort[]= Engine::GetEntity('PluginCompany_Company_CompanyTag', $aRow);//new PluginCompany_ModuleCompany_EntityCompanyTag($aRow);
			}
		}
		return $aReturnSort;
	}

	public function GetCompanyTagsByCompanyId($iCompanyId) {
		$sql = "SELECT
			company_tag_text
			FROM
				".Config::Get('db.table.company_tag')."
			WHERE
				company_id = ?d
				";
		$aReturn=array();
		if ($aRows=$this->oDb->select($sql,$iCompanyId)) {
			foreach ($aRows as $aRow) {
				$aReturn[]=$aRow['company_tag_text'];
			}

		}
		return $aReturn;
	}

	public function GetCompanyTagsByLike($sTag,$iLimit) {
		$sTag=mb_strtolower($sTag,"UTF-8");
		$sql = "SELECT
				company_tag_text
			FROM
				".Config::Get('db.table.company_tag')."
			WHERE
				company_tag_text LIKE ?
			GROUP BY
				company_tag_text
			LIMIT 0, ?d
				";
		$aReturn=array();
		if ($aRows=$this->oDb->select($sql,$sTag.'%',$iLimit)) {
			foreach ($aRows as $aRow) {
				$aReturn[]= Engine::GetEntity('PluginCompany_Company_CompanyTag', $aRow);//new PluginCompany_ModuleCompany_EntityCompanyTag($aRow);
			}
		}
		return $aReturn;
	}

	public function GetCompaniesByArrayId($aArrayId) {
		if (!is_array($aArrayId) or count($aArrayId)==0) {
			return array();
		}

		$sql = "SELECT
					*
				FROM
					".Config::Get('db.table.company')." as c
				WHERE
				company_id IN(?a)
				ORDER BY FIELD(company_id,?a) ";
		$aCompanies=array();
		if ($aRows=$this->oDb->select($sql,$aArrayId,$aArrayId)) {
			foreach ($aRows as $oCompany) {
				$aCompanies[]=Engine::GetEntity('PluginCompany_Company_Company', $oCompany);
			}
		}
		return $aCompanies;
	}

	public function GetCompaniesByTag($sTag,&$iCount,$iCurrPage,$iPerPage) {
		$sWhere = $this->MakeActivateFilter();
		$sql = "SELECT
			c.company_id
			FROM (
					SELECT
						company_id
					FROM
						".Config::Get('db.table.company_tag')."
					WHERE
						company_tag_text = ?
				) as ct
				JOIN ".Config::Get('db.table.company')." AS c ON ct.company_id = c.company_id
				".$sWhere."
				ORDER BY company_rating DESC
                LIMIT ?d, ?d";
		$aCompanies=array();
		if ($aRows=$this->oDb->selectPage($iCount,$sql,$sTag,($iCurrPage-1)*$iPerPage, $iPerPage)) {
			foreach ($aRows as $aCompany) {
				$aCompanies[]= $aCompany['company_id'];
			}
		}
		return $aCompanies;
	}

	public function GetCompaniesByFilter($aFilter,$aOrder,&$iCount,$iCurrPage,$iPerPage) {
		$aOrderAllow=array('company_id','company_name','company_date_add','company_rating','company_count_feedback','company_count_favourite');
		$sOrder='';
		foreach ($aOrder as $key=>$value) {
			if (!in_array($key,$aOrderAllow)) {
				unset($aOrder[$key]);
			} elseif (in_array($value,array('asc','desc'))) {
				$sOrder.=" {$key} {$value},";
			}
		}
		$sOrder=trim($sOrder,',');
		if ($sOrder=='') {
			$sOrder=' company_rating desc ';
		}
		$sWhere = $this->buildFilter($aFilter);
		$sql = "SELECT
					company_id
				FROM
					".Config::Get('db.table.company')."
				WHERE
					".$sWhere."
				ORDER by {$sOrder}
				LIMIT ?d, ?d ;
					";
		$aResult=array();
		if ($aRows=$this->oDb->selectPage($iCount,$sql,
			($iCurrPage-1)*$iPerPage, $iPerPage
		)) {
			foreach ($aRows as $aRow) {
				$aResult[]=$aRow['company_id'];
			}
		}
		return $aResult;
	}
	public function GetCountCompaniesByFilter($aFilter) {
		$sWhere = $this->buildFilter($aFilter);
		$sql = "SELECT count(company_id) as count
				FROM
					".Config::Get('db.table.company')."
				WHERE ".$sWhere;
		if ($aRow=$this->oDb->selectRow($sql)) {
			return $aRow['count'];
		}
		return false;
	}

	public function GetCountCompaniesByTag($sTag) {
		$sql = "SELECT
					count(company_id) as count
				FROM
					".Config::Get('db.table.company_tag')."
				WHERE
					company_tag_text = ? ;
					";
		if ($aRow=$this->oDb->selectRow($sql,$sTag)) {
			return $aRow['count'];
		}
		return false;
	}
	protected function buildFilter($aFilter) {
		$sWhere = '1=1 ';
		if(isset($aFilter['active']))
			$sWhere .= ' AND company_active = '.$aFilter['active'];
		if(isset($aFilter['type']))
			$sWhere .= " AND company_type = '".$aFilter['type']."'";
		if(isset($aFilter['name_like']))
			$sWhere .= " AND LOWER(company_name) LIKE '%{$aFilter['name_like']}%'";
		if(isset($aFilter['blog_id']))
			$sWhere .= " AND blog_id IN ('".join("', '",$aFilter['blog_id'])."')";
		if(isset($aFilter['company_id']))
			$sWhere .= " AND company_id IN ('".join("', '",$aFilter['company_id'])."')";
		if(isset($aFilter['new_time']))
			$sWhere .= ' AND company_date_add >= "'.date("Y-m-d H:00:00",time()-$aFilter['new_time']).'"';
		if(isset($aFilter['company_type']))
			$sWhere .= " AND company_type IN ('".join("', '",$aFilter['company_type'])."')";
		return $sWhere;
	}

	/* СВЯЗЬ ПОЛЬЗОВАТЕЛЕЙ С КОМПАНИЕЙ */

	public function UpdateCompanyOwner(ModuleBlog_EntityBlog $oBlog) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				user_owner_id = ?d
			WHERE
				blog_id = ?d
		";
		if ($this->oDb->query($sql,$oBlog->getOwnerId(),$oBlog->getId())) {
			return true;
		}
		return false;
	}

	public function UpdateCompanyBlogOwner(ModuleBlog_EntityBlog $oBlog) {
		$sql = "UPDATE ".Config::Get('db.table.blog')."
			SET
				user_owner_id = ?d
			WHERE
				blog_id = ?d
		";
		if ($this->oDb->query($sql,$oBlog->getOwnerId(),$oBlog->getId())) {
			return true;
		}
		return false;
	}

	/* ОТЗЫВЫ */

	public function increaseCompanyCountFeedbacks($sCompanyId) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				company_count_feedback=company_count_feedback+1
			WHERE
				company_id = ?
		";
		if ($this->oDb->query($sql,$sCompanyId)) {
			return true;
		}
		return false;
	}

	public function UpdateFeedbackRead(PluginCompany_ModuleCompany_EntityCompanyFeedbackRead $oFeedbackRead) {
		$sql = "UPDATE ".Config::Get('db.table.company_feedback_read')."
			SET
				feedback_count_last = ? ,
				feedback_id_last = ? ,
				date_read = ?
			WHERE
				company_id = ?
				AND
				user_id = ?
		";
		return $this->oDb->query($sql,$oFeedbackRead->getFeedbackCountLast(),$oFeedbackRead->getFeedbackIdLast(),$oFeedbackRead->getDateRead(),$oFeedbackRead->getCompanyId(),$oFeedbackRead->getUserId());
	}

	public function AddFeedbackRead(PluginCompany_ModuleCompany_EntityCompanyFeedbackRead $oFeedbackRead) {
		$sql = "INSERT INTO ".Config::Get('db.table.company_feedback_read')."
			SET
				feedback_count_last = ? ,
				feedback_id_last = ? ,
				date_read = ? ,
				company_id = ? ,
				user_id = ?
		";
		return $this->oDb->query($sql,$oFeedbackRead->getFeedbackCountLast(),$oFeedbackRead->getFeedbackIdLast(),$oFeedbackRead->getDateRead(),$oFeedbackRead->getCompanyId(),$oFeedbackRead->getUserId());
	}

	public function GetFeedbackRead($sCompanyId,$sUserId) {
		$sql = "SELECT
					*
				FROM
					".Config::Get('db.table.company_feedback_read')."
				WHERE
					company_id = ?d
					AND
					user_id = ?d
				;
					";
		if ($aRow=$this->oDb->selectRow($sql,$sCompanyId,$sUserId)) {
			return Engine::GetEntity('PluginCompany_Company_CompanyFeedbackRead', $aRow);//new PluginCompany_ModuleCompany_EntityCompanyFeedbackRead($aRow);
		}
		return false;
	}

	/* ТЭГИ */

	public function AddCompanyTag(PluginCompany_ModuleCompany_EntityCompanyTag $oCompanyTag) {
		$sql = "INSERT INTO ".Config::Get('db.table.company_tag')."
			(company_id,
			user_id,
			company_tag_text
			)
			VALUES(?d,  ?d,	?)
		";
		if ($iId=$this->oDb->query($sql,$oCompanyTag->getCompanyId(),$oCompanyTag->getUserId(),$oCompanyTag->getText()))
		{
			return $iId;
		}
		return false;
	}

	public function DeleteCompanyTagsByCompanyId($sCompanyId) {
		$sql = "DELETE FROM ".Config::Get('db.table.company_tag')."
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$sCompanyId)) {
			return true;
		}
		return false;
	}

	public function DeleteCompany($sCompanyId) {
		$sql = "DELETE FROM ".Config::Get('db.table.company')."
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$sCompanyId)) {
			return true;
		}
		return false;
	}

	public function MakeActivateFilter() {
		$iCurrentUserId=-1;
		if (is_object($this->oUserCurrent)) {
			$iCurrentUserId=$this->oUserCurrent->getId();
		}
		if (Config::Get('module.company.use_activate')) {
			if (!$this->oUserCurrent or ($this->oUserCurrent and !$this->oUserCurrent->isAdministrator())){
				return " AND (company_active = 1 OR user_owner_id = ".$iCurrentUserId.')';
			} //'#where' => array('c.company_active = ?d OR c.user_owner_id = ?' => array(1,$iCurrentUserId)); // Для ORM фильтр
		}
		return "";
	}

	public function GetCompanyInactiveBlogs() {
		$aReturn=array();
		if (Config::Get('module.company.use_activate')) {
			$sql = "SELECT blog_id
					FROM ".Config::Get('db.table.company')."
					WHERE company_active = 0;
				   ";

			if ($aRows=$this->oDb->select($sql)) {
				foreach ($aRows as $aRow) {
					$aReturn[]=$aRow['blog_id'];
				}
			}
		}
		return $aReturn;
	}

	public function GetCompanyActiveBlogs() {
		$sWhere = "1=1 ";
		if (Config::Get('module.company.use_activate')) {
			$sWhere .= " AND company_active = 1";
		}

		$sql = "SELECT blog_id
				FROM ".Config::Get('db.table.company')."
				WHERE ".$sWhere;
		$aReturn=array();
		if ($aRows=$this->oDb->select($sql)) {
			foreach ($aRows as $aRow) {
				$aReturn[]=$aRow['blog_id'];
			}
		}
		return $aReturn;
	}

	/*
	* Получает всех пользоватлей которым понравилась компания
	*/
	public function GetFavouriteUsersByTargerId($sTargetId,$sTargetType,$iCurrPage,$iPerPage) {
		$sql = "
			SELECT user_id
			FROM ".Config::Get('db.table.favourite')."
			WHERE
					target_id = ?
				AND
					target_publish = 1
				AND
					target_type = ?
            ORDER BY user_id DESC
            LIMIT ?d, ?d ";

		$aFavourites=array();
		if ($aRows=$this->oDb->selectPage($iCount,
			$sql,
			$sTargetId,
			$sTargetType,
			($iCurrPage-1)*$iPerPage,
			$iPerPage
		)) {
			foreach ($aRows as $aFavourite) {
				$aFavourites[]=$aFavourite['user_id'];
			}
		}
		return $aFavourites;
	}

	/*
		 * Получает компании которые понравились пользователю
		 */
	public function GetFavouriteCompaniesByUserId(&$iCount,$sUserId,$iCurrPage,$iPerPage) {
		$sWhere = "1=1 ".$this->MakeActivateFilter();
		$sql = "
			SELECT c.*
			FROM ".Config::Get('db.table.favourite')." as f,".Config::Get('db.table.company')." as c
			WHERE ".$sWhere."
				AND	f.user_id = ? AND f.target_type = 'company' AND f.target_id = c.company_id
            ORDER BY c.company_rating DESC
            LIMIT ?d, ?d ";
		$aReturn=array();
		if ($aRows=$this->oDb->selectPage($iCount,
			$sql,
			$sUserId,
			($iCurrPage-1)*$iPerPage,
			$iPerPage
		)) {
			foreach ($aRows as $aRow) {
				$aReturn[]= Engine::GetEntity('PluginCompany_Company_Company', $aRow);
			}
		}
		return $aReturn;
	}

	public function increaseCompanyCountSubscribe($sCompanyId) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				company_count_subscribe = company_count_subscribe + 1
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$sCompanyId)) {
			return true;
		}
		return false;
	}

	public function decreaseCompanyCountSubscribe($sCompanyId) {
		$sql = "UPDATE ".Config::Get('db.table.company')."
			SET
				company_count_subscribe = company_count_subscribe - 1
			WHERE
				company_id = ?d
		";
		if ($this->oDb->query($sql,$sCompanyId)) {
			return true;
		}
		return false;
	}


}

?>