CREATE TABLE IF NOT EXISTS `prefix_company` (
  `company_id` INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  `blog_id` INTEGER(11) UNSIGNED NOT NULL,
  `user_owner_id` INTEGER(11) UNSIGNED NOT NULL,
  `company_url` VARCHAR(200) NOT NULL DEFAULT '',
  `company_name` VARCHAR(255) NOT NULL DEFAULT '' COLLATE utf8_general_ci,
  `company_name_legal` VARCHAR(255) DEFAULT NULL,
  `company_description` TEXT NOT NULL,
  `company_tags` VARCHAR(255) NOT NULL DEFAULT '',
  `company_country` VARCHAR(30) DEFAULT NULL,
  `company_city` VARCHAR(30) DEFAULT NULL,
  `company_address` VARCHAR(100) DEFAULT NULL,
  `company_site` VARCHAR(100) DEFAULT NULL,
  `company_phone` VARCHAR(50) DEFAULT NULL,
  `company_fax` VARCHAR(50) DEFAULT NULL,
  `company_skype` varchar(50) DEFAULT NULL,
  `company_icq` varchar(12) DEFAULT NULL,
  `company_contact_name` VARCHAR(50) DEFAULT NULL,
  `company_contact_info` varchar(255) DEFAULT NULL,
  `company_date_basis` DATETIME DEFAULT NULL,
  `company_vacancies` TEXT DEFAULT NULL,
  `company_email` VARCHAR(50) DEFAULT NULL,
  `company_logo` TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  `company_logo_type` VARCHAR(5) DEFAULT NULL,
  `company_date_add` DATETIME NOT NULL,
  `company_date_edit` DATETIME DEFAULT NULL,
  `company_date_activation` DATETIME DEFAULT NULL,
  `company_rating` FLOAT(9,3) NOT NULL DEFAULT '0.000',
  `company_count_workers` INTEGER(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_count_vote` INTEGER(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_count_feedback` INTEGER(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_count_favourite` INT(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_count_subscribe` INT(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_latitude` varchar(255) default NULL,
  `company_longitude` varchar(255) default NULL,
  `company_type` enum('base') DEFAULT 'base',
  `company_file_name` varchar(50) DEFAULT NULL,
  `company_active` TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  `company_prefs` TEXT,
  `company_fields` TEXT,
  `company_about` TEXT,
  `company_about_source` TEXT,
  `topic_id_last` INTEGER(11) UNSIGNED NOT NULL DEFAULT '0',
  `company_tariff_id` TINYINT(1) UNSIGNED NOT NULL DEFAULT '0',
  `company_date_tariff_end` DATETIME DEFAULT NULL,

  PRIMARY KEY (`company_id`),
   KEY user_owner_id (user_owner_id),
   KEY blog_id (blog_id),
   KEY company_url (company_url),
   KEY company_name (company_name),
   KEY company_type (company_type),
  CONSTRAINT prefix_company_fk FOREIGN KEY (user_owner_id) REFERENCES prefix_user (user_id) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT prefix_company_fk1 FOREIGN KEY (blog_id) REFERENCES prefix_blog (blog_id) ON DELETE CASCADE ON UPDATE CASCADE
)ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `prefix_company_tag` (
  `company_tag_id` INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  `company_id` INTEGER(11) UNSIGNED NOT NULL,
  `user_id` INTEGER(11) UNSIGNED NOT NULL,
  `company_tag_text` VARCHAR(50) COLLATE utf8_general_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`company_tag_id`),
  KEY `company_id` (`company_id`),
  KEY `user_id` (`user_id`),
  KEY `company_tag_text` (`company_tag_text`),
  CONSTRAINT `prefix_company_tag_fk` FOREIGN KEY (`company_id`) REFERENCES `prefix_company` (`company_id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `prefix_company_tag_fk1` FOREIGN KEY (`user_id`) REFERENCES `prefix_user` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
)ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;


CREATE TABLE IF NOT EXISTS `prefix_company_feedback_read` (
  `company_id` INTEGER(11) UNSIGNED NOT NULL,
  `user_id` INTEGER(11) UNSIGNED NOT NULL,
  `date_read` DATETIME NOT NULL,
  `feedback_count_last` INTEGER(10) UNSIGNED NOT NULL DEFAULT '0',
  `feedback_id_last` INTEGER(11) NOT NULL DEFAULT '0',
  UNIQUE KEY `company_id_user_id` (`company_id`, `user_id`),
  KEY `company_id` (`company_id`),
  KEY `user_id` (`user_id`),
  CONSTRAINT `prefix_company_feedback_read_fk` FOREIGN KEY (`company_id`) REFERENCES `prefix_company` (`company_id`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `prefix_company_feedback_read_fk1` FOREIGN KEY (`user_id`) REFERENCES `prefix_user` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
)ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `prefix_company_staff` (
  `company_id` int(11) unsigned NOT NULL,
  `staff_name` varchar(100) NOT NULL,
  `staff_position` varchar(100) DEFAULT NULL,
  `user_id` int(11) unsigned DEFAULT NULL,
  KEY `company_id` (`company_id`),
  CONSTRAINT `prefix_company_staff_fk` FOREIGN KEY (`company_id`) REFERENCES `prefix_company` (`company_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `prefix_company_photo` (
	`id` INT(11) NOT NULL AUTO_INCREMENT,
	`company_id` INT(11) UNSIGNED NULL DEFAULT NULL,
	`path` VARCHAR(255) NOT NULL,
	`description` TEXT NULL,
	`target_tmp` VARCHAR(40) NULL DEFAULT NULL,
	PRIMARY KEY (`id`),
	INDEX `company_id` (`company_id`),
	INDEX `target_tmp` (`target_tmp`),
	CONSTRAINT `prefix_company_photo_fk_1` FOREIGN KEY (`company_id`) REFERENCES `prefix_company` (`company_id`) ON UPDATE CASCADE ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;

